********************************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 5: GENERATES DEMOGRAPHIC, EDUCATION, LABOR MARKET, AND OTHER DERIVED VARIABLES
*
* N. Millan's December 27, 2012 do-file
* Education section updated by G. Pierre and T. Rajadel in July 2013
* Hours variable corrected on Sept 25, 2013
* Size of establishment & Informality sections updated by S. Monroy Taborda on January 22 2014
*
* Created: December 27, 2012
* Last updated: April 25, 2014
********************************************************************************************************************

/*
As of April 25, 2014 the STEP countries are:
	- Bolivia
	- Colombia
	- Laos
	- Sri Lanka
	- Vietnam
	- Yunnan
	- Ukraine

This do file uses STEP data to:
	1. Create demographic variables:
		age age_g age_g2 age2 gender marital_status life_sat chronic 
	2. Create education-related variables:
		ece, certificate, current, dropout, interrupt, training, apprenticeship
		ISCED, ISCED_v, ISCED_p, highest_field_1, highest_field_2, current_ISCED, current_ISCED_v, current_field, dropout_ISCED, 
		dropout_level dropout_field training_field_1 training_field_2
	3. Create labor market variables
	4. Others

It is based on Natalia Millan's December 27, 2012 do-file.

*/


global pathworkingdata

 
**************************************************************** LOOP THROUGH ALL COUNTRIES ************************************************************************


foreach country in "Bolivia" "Laos" "Sri Lanka" "Vietnam" "Yunnan" "Colombia" {
	
use "$pathworkingdata/STEP `country'_working.dta", clear

***************************************************************************************************************
************************** AGE, AGE GROUPS, GENDER AND OTHER DEMOGRAPHIC VARS *********************************
***************************************************************************************************************
*GENDER
gen gender =1 if m1a_q02 ==2
replace gender=0 if m1a_q02 ==1
label define gender 1 "Female" 0 "Male" 
label values gender gender
label var gender Gender

*AGE
gen age=m1a_q04

*AGE SQUARED
gen age2=age*age


*MARITAL STATUS /*DUMMY equal to one if person has a spouse*/
gen has_spouse=1 if m1a_q13==1|m1a_q13==2 |m1a_q13==3
replace has_spouse=0 if m1a_q13==4 |m1a_q13==5
replace has_spouse=0 if m1a_q13==6 
replace has_spouse=0 if m1a_q13==7
label 	var	has_spouse	"Has a spouse"
*replace marital_stat=5 if m1a_q13==8
*label define marital_stat 1 "Married/Cohab" 2 "Sep/Div" 3 "Widowed" 4 "Single" 5 "Other", replace

*LIFE SATISFACTION
gen life_sat=m3_q01
replace life_sat=.a if life_sat==92
label var life_sat "Life satisfaction"
 
*HAS A CHRONIC DISEASE
recode m3_q05(2=0), gen(chronic)
label define chronic 1 "Has a chronic disease" 0 "Doesn't have a chronic disease", replace
label values chronic chronic
label var chronic "Chronic disease" 

*NUMBER OF SIBLINGS AT AGE 12
gen old_brothers=m7a_q18
gen old_sisters=m7a_q19
gen young_brothers=m7a_q20
gen young_sisters=m7a_q21
replace old_brothers=.a if m7a_q18==92|m7a_q18==99
replace old_sisters=.a if m7a_q19==92|m7a_q18==99
replace young_brothers=.a if m7a_q20==92|m7a_q18==99
replace young_sisters=.a if m7a_q21==92|m7a_q18==99
label var young_brothers "Number of younger brothers at age 12"
label var young_sisters "Number of younger sisters at age 12"
label var old_brothers "Number of younger brothers at age 12"
label var old_sisters "Number of older sisters at age 12"



*FAMILY STRUCTURE AT AGE 12 
gen father_mother=1 if m7a_q22_1 ==1 & m7a_q22_2==1
replace father_mother=0 if m7a_q22_1==2 & m7a_q22_2==2
replace father_mother=2 if father_mother==.
label define father_mother 0 "Didn't live with father & mother"  2 "Lived with father & mother" 3 "DK/RF" 
label values father_mother father_mother
label var father_mother "Lived with mother and father at age 12"

*NUMBER OF SHOCKS BEFORE AGE 15
if country=="Sri Lanka" {
	gen m7a_q24_11=1 if m7a_q24_11_1==1 | m7a_q24_11_2==1
	replace m7a_q24_11=0 if m7a_q24_11_1==2 | m7a_q24_11_2==2
}
foreach num of numlist 1/11 {
foreach var of varlist m7a_q24_`num' {
recode m7a_q24_`num' (0=.) (2=0)
}
}

gen shocks=(m7a_q24_1 + m7a_q24_2 + m7a_q24_3 + m7a_q24_4 + m7a_q24_5 + m7a_q24_6  + m7a_q24_7 + m7a_q24_8 + m7a_q24_9 + m7a_q24_10 )
replace shocks=shocks+1 if m7a_q24_11<. & m7a_q24_11!=0			   
label var shocks "Number of economic shocks before age 15" 
gen shocks2=shocks	
replace shocks2=2 if shocks2>=2 & shocks2<.
label define shocks2 0 "No shocks" 1 "One shock" 2 "Two or more shocks", replace
label values  shocks2 shocks2
label var shocks2 "Index for number of economic shocks before age 15" 
display "`country'" 
tab shocks2 if elegido==1

gen shocks_dummy=0 if shocks2==0	
replace shocks_dummy=1 if shocks2>=1 & shocks2<=2
label define shocks_dummy 0 "No shocks" 1 "At least one shock", replace
label values  shocks_dummy shocks_dummy
label var shocks_dummy "Dummy for economic shocks before age 15" 
*OVERWEIGHT, UNDERWEIGHT AND OBESITY
		recode m3_q03 (888=.) (9=.) (0=.) (92=.) /*HEIGHT*/
		recode m3_q02 (888=.) (9=.) (0=.)  /*WEIGHT*/ 
		replace m3_q02=m3_q02/100 /*Convert centimeters to meters*/
		gen BMI=m3_q03/(m3_q02*m3_q02) /*Weight over height squared*/
		replace BMI=round(BMI, .1)
		gen  BMI_class=1 if  BMI <18.5
		replace BMI_class=2 if BMI>18.5 & BMI<25
		replace BMI_class=3 if BMI>=25 & BMI <=29
		replace BMI_class=4 if BMI>=30 & BMI<. 
		label define BMI_class 1 Underweight 2 Normal 3 Overweight 4 Obese, replace 
		label values BMI_class BMI_class
		label var BMI_class "BMI classification" 
		label var BMI "Body Mass Index" 
		notes  BMI: "A BMI under 16 is extremely emaciated; a BMI of 15 signals starvation. BMI's over 40 signal morbid obesity." 
*PARENTAL INVOLVEMENT IN EDUCATION
	gen parental =m2_q46
	label var parental "Parental involvement in education"
*SOCIOECONOMIC STATUS AT AGE 15
recode m7a_q23 (0=.) (1=1) (2=1) (3=1) (4=2) (5=2) (6=2) (7=3) (8=3) (9=3) (10=3), gen(ses)
	label define ses 1 "Low SES" 2 "Middle SES" 3 "High SES", replace
	label values ses ses
	label var ses "Socioeconomic status at age 15"	
	
	
****** MOTHER TONGUE ******
if country=="Bolivia" {
	gen mother_tongue= 1 if m7a_q01_1==1 & m7a_q01_2==.  /*Spanish only*/
	replace mother_tongue=0 if m7a_q01_1==1 & m7a_q01_2<.& m7a_q01_2!=9  /*Spanish and other*/
	replace mother_tongue=0 if  m7a_q01_1<. & m7a_q01_2==1 & m7a_q01_1!=9  /*Spanish and other*/
	replace  mother_tongue=0 if m7a_q01_1>1 & m7a_q01_1<.& m7a_q01_1!=9 & m7a_q01_2!=1 & m7a_q01_2!=9 /*Other*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Spanish only" 0 "Other or Spanish & other"
	lab values mother_tongue mother_tongue
}
if country=="Colombia" {
	gen mother_tongue= 1 if m7a_q01_1==1  /*Spanish only*/
	replace  mother_tongue=0 if m7a_q01_1==5 /*Other*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Spanish only" 0 "Other"
	lab values mother_tongue mother_tongue
}
if country=="Laos" {
	gen mother_tongue= 1 if m7a_q01_1==1 & m7a_q01_2==. 		/*Lao only*/
	replace mother_tongue= 1 if m7a_q01_1==. & m7a_q01_2==1 	/*Lao only*/
	replace mother_tongue=0 if m7a_q01_1==1 & m7a_q01_2<.	/*Lao & other*/
	replace mother_tongue=0 if m7a_q01_1<. & m7a_q01_2==1 		/*Other & Lao*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_1<. 								 /*other only*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_2<. 								 /*other only*/
	label var mother_tongue "Mother tongue"
	label define mother_tongue 1 "Lao only" 2 "Lao & other" 3 "Other", replace
	label values mother_tongue mother_tongue
}
if country=="Sri Lanka" {
	gen mother_tongue= 1 if m7a_q01_1==1     /*Sinhala only*/
	replace  mother_tongue= 0 if  m7a_q01_2==1 		/*Sinhala only/ & other including Tamil*/
	replace mother_tongue= 0 if m7a_q01_1==2 &  m7a_q01_2!=1 	/*Tamil only/& other excluding Sinhala*/
	replace mother_tongue= 0 if m7a_q01_1!=1 &  m7a_q01_2==2 	/*Tamil only/& other excluding Sinhala*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_1<. 								 /*other only*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_2<. 								 /*other only*/
	label var mother_tongue "Mother tongue"
	label define mother_tongue 1 "Sinhala/Sinhala & other" 2 "Tamil/Tamil & other exc. Sinhala" 3 "Other", replace
	label values mother_tongue mother_tongue
}
if country=="Vietnam" {
	replace m7a_q01_2=. if m7a_q01_2==0
	replace m7a_q01_1=. if m7a_q01_1==0
	gen mother_tongue= 1 if m7a_q01_1==1 & m7a_q01_2==. 		/*Vietnamese only*/
	replace mother_tongue= 1 if m7a_q01_1==0 & m7a_q01_2==1 	/*Vietnamese only*/
	replace mother_tongue= 1 if m7a_q01_1==. & m7a_q01_2==1 	/*Vietnamese only*/
	replace mother_tongue=0 if m7a_q01_1==4 & m7a_q01_2==. 		/*Chinese only*/
	replace mother_tongue=0 if m7a_q01_2==1 & m7a_q01_1==4 		/*Vietnamese and Chinese*/
	replace mother_tongue=0 if m7a_q01_2==4 & m7a_q01_1==1 		/*Chinese and Vietnamese*/
	
	replace  mother_tongue=0 if m7a_q01_1>1 & m7a_q01_1<. & m7a_q01_1!=4 & m7a_q01_1!=0 & m7a_q01_2!=1 & m7a_q01_2!=4 /*Vietnamese/Chinese & other/other only*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_1<. 								 /*Vietnamese/Chinese & other/other only*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_2<. 								 /*Vietnamese/Chinese & other/other only*/
	label var mother_tongue "Mother tongue"
	label define mother_tongue 1 "Vietnamese only" 2 "Vietnamese & Chinese/Chinese only" 3 "Vietnamese/Chinese & other/other only", replace
	label values mother_tongue mother_tongue
}
if country=="Yunnan" {
	gen mother_tongue= 1 if m7a_q01_1==2 & m7a_q01_2==. /*Yunnan dialect only*/
	replace mother_tongue= 1 if m7a_q01_1==. & m7a_q01_2==2 /*Yunnan dialect only*/  
	replace mother_tongue=0 if m7a_q01_1==1 & m7a_q01_2==. /*Mandarin only*/
	replace mother_tongue=1 if m7a_q01_2==1 & m7a_q01_1==2	/*Yunnan and Mandarin*/
	replace mother_tongue=1 if m7a_q01_2==2 & m7a_q01_1==1 /*Yunnan and Mandarin*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_1<. /*Other*/
	replace  mother_tongue=0 if mother_tongue==. & m7a_q01_1<. /*Other*/
	label var mother_tongue "Mother tongue"
	label define mother_tongue 1 "Yunnan dialect only" 2 "Yunnan dialect & Mandarin/Mandarin only" 3 "Other", replace
	label values mother_tongue mother_tongue
}
	
****************************************** END OF AGE, AGE GROUPS, GENDER AND OTHER DEMOGRAPHIC VARS ******************************************


***************************************************************************************************************************
**************************************** LABOR MARKET *********************************************************************
***************************************************************************************************************************
/*"Employed" if:
- worked at least one hour in the past 7 days (q01-03)
- OR reported undertaking an occasional job in the past 7 days (q04)
- OR is currently absent from a permanent / long term job and will return to the same job (q05 & q06) */

/*  "Unemployed":
- did not work in the past 7 days (answered no to q01 to q04)
- AND is not currently absent from a permanent / long term job (no to q05) OR will not be returning to the same job (yes to q05, but either no or doesn't know to q06)
- AND is looking for a job (q07) or trying to set up a business (q08)
- AND is available to start work within the next two weeks */

/*"Out of the Labor Force if he or she:
- did not work in the past 7 days (answered no to q01 to q04)
- AND is not currently absent from a permanent / long term job (no to q05) OR will not be returning to the same job (yes to q05, but either no or doesn't know to q06)
- AND: 		(i) is NOT looking for a job (q07) NOR trying to set up a business (q08) 
		OR (ii) is looking for a job (q07) OR trying to set up a business (q08) AND, in either case, is not available to start work within the next two weeks (q12)*/

*emp: Dummy variable for worked or held a job in the past week
	gen emp=1 if m4a_q01==1|m4a_q02==1|m4a_q03==1|m4a_q04==1|m4a_q05==1|m4a_q06==1
	replace emp=0 if m4a_q01==2 & m4a_q02==2 & m4a_q03==2 & m4a_q04==2 & m4a_q05==2 
	replace emp=0 if m4a_q06==2
	replace emp=. if m4a_q06==9
	label var emp "Currently working"

*lm_status: Labor market status (employed, unemployed, inactive)	
	gen lm_status=1 if emp==1
	replace lm_status=2 if m4a_q07==1 & m4a_q12==1 /*Looking for work and available in next 2 weeks*/
	replace lm_status=2 if m4a_q08==1 & m4a_q12==1 /*Trying to start business and available in next 2 weeks*/
	replace lm_status=3 if m4a_q07==2 & m4a_q08==2  /*Hasn't looked for work/tried to start a business*/
	replace lm_status=3 if m4a_q07==1 & m4a_q12==2 /*Looking for work but not available in next 2 weeks*/
	replace lm_status=3 if m4a_q08==1 & m4a_q12==2 /*Trying to start business but not available in next 2 weeks*/
	label define  lm_status 1 "Employed" 2 "Unemployed" 3 "Inactive", replace
	label values lm_status lm_status
	label var lm_status "Labor market status"

	tab lm_status, m
*active: Dummy variable for being active in the labor market
	gen active=1 if lm_status==1|lm_status==2
	replace active=0 if lm_status==3 
	label define active 1 Active 0 Inactive
	label values active active
	label var active "Dummy for active in the labor market"

*emp_stat: employment status
	gen emp_status=.
	replace emp_status=1 if m4c_q06==1 & emp==1
	replace emp_status=2 if m4c_q06==2 & emp==1
	replace emp_status=3 if m4c_q06==3 & emp==1
	replace emp_status=3 if  emp==1 & (m4c_q06~=1 & m4c_q06~=2 & m4c_q06~=3)
	lab define emp_status 1 "Employee" 2 "Self-employed" 3 "Unpaid family worker/other", replace
	lab values emp_status emp_status
	lab var emp_status "Employment status" 
	tab emp_status
	
*self_emp: SELF-EMPLOYMENT DUMMY
gen self_emp=1 if emp_stat==2
replace self_emp=0 if emp_stat==1
replace self_emp=0 if emp_stat==3
label var self_emp "Self-employment dummy"
label define self_emp 1 "Self-employed" 0 "Employee/Unpaid family worker/other", replace
label values self_emp self_emp 
	
*emplast12: DUMMY VARIABLE FOR WORKING OR WORKED IN THE LAST 12 MONTHS
	gen emplast12=1 if emp==1							/*Currently working*/	
	replace emplast12=1 if m5a_q02==1   				/*Worked in last 12 months*/
	replace emplast12 =0 if emp<. & emplast12==.
	label var emplast12 "Currently working or worked in last 12 months"

*emp6: DUMMY VARIABLE FOR INDIVIDUALS WHO HAVE WORKED AT LEAST 6 MONTHS SINCE COMPLETED HIGHEST LEVEL OF EDUCATION
	gen emp6=1 if m2_q30==1
	replace emp6 =0 if m2_q30==2  
	label var emp6 "Worked at least 6 months since completed highest level of education"
	notes emp6: Those currently attending formal ed (or w/o formal ed) do not answer this question. 

*Unemployed: 1=unemployed, 0=employed
gen unemployed=1 if lm_status==2
replace unemployed=0 if lm_status==1
label var unemployed "1=unemployed, 0=employed" 

*Employment
gen employed=1 if emp==1
		replace employed=0 if emp!=1 & lm_status<.
		label var employed "1=employed, 0=not employed"

*Wage workers
gen wage_worker=1 if emp_status==1
replace wage_worker=0 if emp==1 & emp_status!=1
label define wage_worker 1 "Wage-worker" 0 "Self-employed or family worker" 
label values wage_worker wage_worker
label var wage_worker "Percent of wage workers" 

*INACTIVE
gen inactive=.
replace inactive=1 if m4a_q09==2 /*Housewife*/
replace inactive=2 if m4a_q09==3|m4a_q09==4 /*Retired/old age*/
replace inactive=3 if m4a_q09==1 /*student*/
replace inactive=4 if m4a_q09==5|m4a_q09==7 /*unfit, don't want to work*/
replace inactive=5 if m4a_q09==12|m4a_q09==13 /*Discouraged*/
replace inactive=6 if m4a_q09==6|m4a_q09==8|m4a_q09==9|m4a_q09==10|m4a_q09==11 /*In transition*/
replace inactive=7 if m4a_q09==14 /*Other*/
replace inactive=8 if lm_stat==3 & inactive==. /*Looking for work but not available in 2 weeks*/
label define inactive 1 Housework 2 "Retired/old age" 3 Student 4 Unfit 5 Discouraged 6 "In transition" 7 Other 8 "Looking for work, not available in next 2 weeks" , replace
label values inactive inactive
label var inactive "Types of inactive population"
display "`country'"
tab inactive

*OCCUPATION
*recoding occupation
gen occupationcode=.
replace occupationcode=m5a_q01_occ_code if m5a_q01_occ_code<.
replace occupationcode=m5a_q02_occ_code if m5a_q01_occ_code==.
label var occupationcode "ISCO Rev.8 occupation code"

gen occupation=.
replace occupation=1 if occupationcode>=110 & occupationcode<=149
replace occupation=2 if occupationcode>=210 & occupationcode<=269
replace occupation=3 if occupationcode>=310 & occupationcode<=369
replace occupation=4 if occupationcode>=410 & occupationcode<=449
replace occupation=5 if occupationcode>=510 & occupationcode<=549
replace occupation=6 if occupationcode>=610 & occupationcode<=639
replace occupation=7 if occupationcode>=700 & occupationcode<=759
replace occupation=8 if occupationcode>=810 & occupationcode<=879
replace occupation=9 if occupationcode>=910 & occupationcode<=969
replace occupation=0 if occupationcode>=0 & occupationcode<=40
label var occupation "1-digit ISCO Rev.8 occupation code"

sum occupation m5a_q01_occ_code m5a_q02_occ_code

*OCCUPATION TYPE
gen occtype=1 if occupation==1 | occupation==2 | occupation==3
replace occtype=2 if occupation>=4 & occupation<=9 
replace occtype=. if emp!=1 /*Only define this variable for currently employed*/

label define occtype 1 "Type A" 2 "Type B", replace
label values occtype occtype
tab occtype, gen(occtype)
rename occtype1 type_a
rename occtype2 type_b
label var type_a "Type A occupation"
label var type_b "Type B occupation"

	
	*OCCUPATION TYPE STEP Aggregation
	gen occtype_step=.
	replace occtype_step=1 if occupationcode>=110 & occupationcode<=369
	replace occtype_step=2 if occupationcode>=410 & occupationcode<610
	replace occtype_step=5 if (occupationcode>=610 & occupationcode<=639)
	replace occtype_step=3 if occupationcode>=700 & occupationcode<=879
	replace occtype_step=4 if occupationcode>=910 & occupationcode<=969
	replace occtype_step=0 if occupationcode>=0 & occupationcode<=40
	label define occtype_step 0 "Military personnel" 1 "Highly skilled white collar - Managers/Professionals/Technicians" 2 "Low skilled white collar" ///
	                      3 "Crafts and related trades workers; Plant and machine operator and assemblers" 4 "Elementary occupations" 5 "Skilled agriculture work", replace
	label value occtype_step occtype_step
	label var occtype_step "Occupation type (STEP Aggregation)"
	
	*LAST OCCUPATION FOR UNEMPLOYED/INACTIVE
	gen last_occ_inun=.
	replace last_occ_inun=1 if m4a_q20>=110 & m4a_q20<=369
	replace last_occ_inun=2 if m4a_q20>=410 & m4a_q20<610
	replace last_occ_inun=5 if m4a_q20>=610 & m4a_q20<=639
	replace last_occ_inun=3 if m4a_q20>=700 & m4a_q20<=879
	replace last_occ_inun=4 if m4a_q20>=910 & m4a_q20<=969
	replace last_occ_inun=0 if m4a_q20>=0 & m4a_q20<=40
	label value last_occ_inun occtype_step
	label var last_occ_inun "Last occupation for inactive/unemployed (STEP Aggregation)" 
	
	*OCCUPATION FOR PEOPLE WHO WORKED IN LAST 12 MONTHS
	destring m4a_q20, replace
	gen     occtype_step_emp12=1 if m4a_q20>=110 &  m4a_q20 <=369
	replace occtype_step_emp12=2 if  m4a_q20>=410 &  m4a_q20<610
	replace occtype_step_emp12=5 if m4a_q20>=610 & m4a_q20<=639
	replace occtype_step_emp12=3 if m4a_q20>=700 & m4a_q20<=879
	replace occtype_step_emp12=4 if m4a_q20>=910 & m4a_q20<=969
	replace occtype_step_emp12=0 if m4a_q20>=0 & m4a_q20<=40
	label values occtype_step_emp12 occtype_step
	label var occtype_step_emp12 "Most recent occupation for those who worked in last 12 months (STEP Aggregation)"	
		
	*ADDITIONAL OCCUPATION INACTIVE & UNEMPLOYED COULD DO (FIRST LISTED, USING TYPE 3 DEFINITION)
	gen     ad_occ_inun=.
	replace ad_occ_inun=1 if m4a_q30_1>=110 & m4a_q30_1<=369
	replace ad_occ_inun=2 if  m4a_q30_1>=410 &  m4a_q30_1<610
	replace ad_occ_inun=5 if m4a_q30_1>=610 & m4a_q30_1<=639
	replace ad_occ_inun=3 if m4a_q30_1>=700 & m4a_q30_1<=879
	replace ad_occ_inun=4 if m4a_q30_1>=910 & m4a_q30_1<=969
	replace ad_occ_inun=0 if m4a_q30_1>=0 & m4a_q30_1<=40
	label value ad_occ_inun occtype_step
	label var ad_occ_inun "First additional occupation, inactive/unemployed (STEP Aggregation)" 
	
	*ADDITIONAL OCCUPATION FOR PEOPLE CURRENTLY WORKING /*LIMITED TO THE FIRST ONE LISTED*/
	gen     ad_occ_current=1 if m4b_q11_1>=110 &  m4b_q11_1<=369
	replace ad_occ_current=2 if  m4b_q11_1>=410 &  m4b_q11_1<610
	replace ad_occ_current=5 if m4b_q11_1>=610 & m4b_q11_1<=639
	replace ad_occ_current=3 if m4b_q11_1>=700 & m4b_q11_1<=879
	replace ad_occ_current=4 if m4b_q11_1>=910 & m4b_q11_1<=969
	replace ad_occ_current=0 if m4b_q11_1>=0 & m4b_q11_1<=40
	label values ad_occ_current occtype_step
	label var ad_occ_current "First additional occupation, currently working (STEP Aggregation)"
	notes ad_occ_current: Refers to first additional occupation the person could work as. 
	
	*ADDITIONAL OCCUPATION FOR PEOPLE WHO WORKED IN LAST 12 MONTHS /*LIMITED TO THE FIRST ONE LISTED*/
	destring m4a_q30_1, replace
	gen     ad_occ_emp12=1 if m4a_q30_1>=110 &  m4a_q30_1 <=369
	replace ad_occ_emp12 =2 if  m4a_q30_1>=410 &  m4a_q30_1<610
	replace ad_occ_emp12 =5 if m4a_q30_1>=610 & m4a_q30_1<=639
	replace ad_occ_emp12 =3 if m4a_q30_1>=700 & m4a_q30_1<=879
	replace ad_occ_emp12 =4 if m4a_q30_1>=910 & m4a_q30_1<=969
	replace ad_occ_emp12 =0 if m4a_q30_1>=0 & m4a_q30_1<=40
	label values ad_occ_emp12 occtype_step
	label var ad_occ_emp12 "First additional occupation, emp last 12 months (STEP Aggregation)"
	notes ad_occ_emp12: Refers to first additional occupation the person could work as. 
	
	*PERMANENT POSITION 
	gen permanent=1 if m4c_q23==4
	replace permanent=0 if m4c_q23<4 & m4c_q23<.
	replace permanent=0 if m4c_q23==5
	label var permanent "Permanent position" 
	notes permanent: Corresponds to main job. 

	*GOVERNMENT EMPLOYMENT
	/*NOTE: Dummy only takes on values for employees. Should it be also take into account the self-employed in the zero category?*/
	*Dummy for government employee
	gen pub_emp=1 if m4c_q19==1|m4c_q19==2
	replace pub_emp=0 if m4c_q19<. & pub_emp!=1
	label var pub_emp "Public/Private employee"
	label define pub_emp 1 "public sector" 0 "private sector", replace
	label values pub_emp pub_emp
	label var pub_emp "Public or private sector employee"
	notes pub_emp: 1 = govt employee, 0=private employee
	notes pub_emp: Corresponds to main job. 

	*SIZE OF ESTABLISHMENT
	gen size_est=1 if m4c_q21==1
	replace size_est=3 if inrange(m4c_q21, 5, 9)
	replace size_est=2 if inrange(m4c_q21, 2, 4)
	replace size_est=1 if m4c_q17==2 & size_est==. /*Self-employed who do not have paid employees*/
	replace size_est=1 if m4c_q16==2 & size_est==. /*Self-employed who do not have unpaid employees*/

	label define size_est 1 "One" 2 "2 to 15" 3 "16 and more", replace
	label values size_est size_est
	label var size_est "Category for number of paid workers in establishment"
	notes size_est: Corresponds to main job. 

	
	*EMPLOYMENT CONTRACT
	gen contract=1 if m4c_q18==1| m4c_q18==2
	replace contract=0 if m4c_q18==3
	label var contract "Has written employment contract" 
	notes contract: Corresponds to main job. 
	
	*SOCIAL SECURITY BENEFITS
	gen benefits =1 if m4c_q22==1
	replace benefits=0 if m4c_q22==2
	label var benefits "Receives social security benefits at work" 
	
	*INFORMAL/FORMAL
	/* Assumptions:
	1. Individuals who are currently working and reported not having social security or benefits are informal
	2. Individuals who reported being an unpaid worke on family business are informal
	3. Individuals who reported being self employed and their reported size of establishment is 1 (including themselves) are informal
	*/

	gen informal=1 if benefits==0
	replace informal=0 if benefits==1  
	replace informal=1 if (m4c_q06==3 | m4c_q06==5) & emp==1 /* ASSUMPTION: INDIVIDUALS WHO REPORTED 
																			BEING AN UNPAID WORKER IN FAMILY BUSINES*/
	replace informal=1 if (m4c_q06==2 & size_est==1 & emp==1) & informal==. /*ASSUMPTION: INDIVIDUALS WHO REPORTED ///
																							BEING SELF EMPLOYED AND DO NOT HAVE PAID WORKERS ARE CONSIDERED INFORMAL*/
	label define informal 1 "Informal" 0 "Formal" 
	label values informal informal
	label var informal "Informal dummy"	
	
	gen informal_wage=1 if informal==1 & wage_worker==1
	replace informal_wage=0 if informal==0 & wage_worker==1
	gen informal_self=1 if informal==1 & self_emp==1
	replace informal_self=0 if informal==0 & self_emp==1
	label define informal_wage 1 "Informal wage worker" 0 "Formal wage worker", replace
	label values informal_wage informal_wage
	label var informal_wage "Informal (only wage workers)"
	label define informal_self 1 "Informal self-employed" 0 "Formal self-employed", replace
	label values informal_self informal_self
	label var informal_self "Informal (only self-employed)"
	notes  informal: "Informality is defined as having SS benefits through job" 
	notes  informal_wage: "Informality is defined as having SS benefits through job/unpaid family worker/other" 
	notes  informal_self: "Informality is defined as having SS benefits through job/unpaid family worker/other" 
	
	
*TENURE IN CURRENT JOB (use number of months so the variable can be squared)
	/*Note: some people have been working zero months*/
	if country=="Sri Lanka" {
		rename  m4c_q03m  m4c_q03_m
		rename  m4c_q03y  m4c_q03_y
	}
	 foreach var of varlist m4c_q03_m m4c_q03_y  {	 /*Change non-response to missing*/
		replace `var' = . if `var'==99
		} 
	 gen tenure=m4c_q03_m
	 replace tenure =(m4c_q03_y*12) if tenure==.
	 replace tenure =(m4c_q03_y*12) if tenure==0
	 replace tenure=m4c_q03_m if m4c_q03_m==0 & m4c_q03_y==.
     gen tenure_squared=tenure*tenure           
	 label var tenure "Number of months in current job"
	 label var tenure_squared "Tenure squared"
	 
*EXPERIENCE NEEDED FOR JOB
	gen exp_needed=m5b_q23
	replace exp_needed=. if exp_needed==9
	label define m5b_q23 1 "None" 2 "Less than 1 year" 3 "1-2 years" 4 "3-5 years" 5 "6-10 years" 6 "More than 10 years", replace 
	label values exp_needed m5b_q23
	label var exp_needed "Years of work experience needed for the job"
	notes exp_needed: Corresponds to main job. 

*TIME NEEDED TO DO A GOOD JOB
	gen time_needed=m5b_q23
	replace time_needed=. if time_needed==9
	label define time_needed 1 "Less than 1 week" 2 "1 week to 1 month" 3 "1-6 months" ///
							4 "7-12 months" 5 "More than 1 year" 6 "More than 10 years", replace 
	label values time_needed time_needed
	label var time_needed "Time to learn to do job well with experience and education needed"
	notes time_needed: Corresponds to main job.

*DOES PERSON'S TENURE FALL WITHIN THE TIME TO DO A GOOD JOB CATEGORIES?
	gen tenure_range=1 if tenure==0|tenure==1
	replace tenure_range=3 if tenure>=1 & tenure<=6
    replace tenure_range=4 if tenure>=7 & tenure<=12
	replace tenure_range=5 if tenure>12 & tenure<=120
	replace tenure_range=6 if tenure>120 & tenure<.
	*Combine less than a week with 1 week to a month
	recode time_needed (2=1), gen(time_needed2)
	
	gen tenure_dif=1 if (tenure_range-time_needed2)<0
	replace tenure_dif=2 if (tenure_range-time_needed2)==0
	replace tenure_dif=3 if (tenure_range-time_needed2)>0 & (tenure_range-time_needed2)<.
	label define tenure_dif 1 "Has less tenure than needed" 2 "Has same tenure as needed" 3 "Has more tenure than needed", replace
	label values tenure_dif tenure_dif
	label var tenure_dif "Difference between tenure and time needed to do job well" 
	
	drop time_needed2
	
*DIF B/T AGE & AGE AT END OF STUDIES
	gen exp_proxy=age-m2_q29
	label var exp_proxy "Diference between age and aprox age at end of studies"
	replace exp_proxy=. if exp_proxy<0 /*This variable should not be negative*/

*ECONOMIC SECTOR OF MAIN JOB
	gen econ_sector=m4b_q04_1 if m4b_q01_1==m4c_q01_code
	replace econ_sector = m4b_q04_2 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_2  /*For ppl whose main occupation was listed second*/
	replace econ_sector = m4b_q04_3 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_3  /*For ppl whose main occupation was listed third*/	
	replace econ_sector = m4b_q04_4 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_4  /*For ppl whose main occupation was listed fourh*/	

if country=="Colombia" | country=="Laos" | country=="Sri Lanka" | country=="Vietnam" {		/*economic sector coded to 3 digits, ISIC rev.4*/
	replace econ_sector=1 if econ_sector>=10 & econ_sector<=99  /*Agriculture, fishery, mining*/
	replace econ_sector=2 if econ_sector>=100 & econ_sector<=339 /*Manufacturing*/
	replace econ_sector=4 if econ_sector>=340 & econ_sector<=399 /*Other services*/ 
	replace econ_sector=2 if econ_sector>=410  & econ_sector<=439 /*Construction*/
	replace econ_sector=3 if econ_sector>=450  & econ_sector<=479 /*Commerce*/
	replace econ_sector=4 if econ_sector>=490  & econ_sector<=999 /*Other services*/

}
if country=="Bolivia" | country=="Yunnan" {		/*economic sector coded to 2 digits, ISIC rev.4*/
	replace econ_sector=1 if econ_sector>=1 & econ_sector<=9  /*Agriculture, fishery, mining*/
	replace econ_sector=2 if econ_sector>=10 & econ_sector<=33 /*Manufacturing*/
	replace econ_sector=4 if econ_sector>=35 & econ_sector<=39 /*Other services*/ 
	replace econ_sector=2 if econ_sector>=41  & econ_sector<=43 /*Construction*/
	replace econ_sector=3 if econ_sector>=45  & econ_sector<=47 /*Commerce*/
	replace econ_sector=4 if econ_sector>=49  & econ_sector<=99 /*Other services*/
	replace econ_sector=. if econ_sector==34
}

	label var econ_sector "Economic sector"
	label define econ_sector 1 "Agriculture, fishery, mining" 2 "Manufacturing & construction" 3 "Commerce"  4 "Other services", replace
	label values econ_sector econ_sector		
		
*FOR SELF-EMPLOYED: WOULD LIKE TO EXPAND BUSINESS
gen expand=1 if m4c_q10==2
replace expand=2 if m4c_q11==1
replace expand=3 if m4c_q11==2
label define expand 1 "No" 2 "Yes, but constraint" 3 "Yes, no constraint" 
label var expand "Desire to expand business and if so, if face constraints"
label values expand expand

*NET PROFIT (FOR SELF-EMPLOYED)
gen net_profit =.
replace net_profit=.a if m4c_q09_amnt==92
replace net_profit =.a if m4c_q09_amnt==1.2 /*STRANGE NUMBER*/
replace net_profit=m4c_q09_amnt*4 if m4c_q09_period==1 /*week*/
replace net_profit=m4c_q09_amnt if m4c_q09_period==2 /*month*/
replace net_profit=m4c_q09_amnt*2 if m4c_q09_period==3 /*fortnight*/
replace net_profit=m4c_q09_amnt/3 if m4c_q09_period==4 /*trimester*/
replace net_profit=m4c_q09_amnt/6 if m4c_q09_period==5 /*semester*/
replace net_profit=m4c_q09_amnt/12 if m4c_q09_period==6 /*year*/
replace net_profit=m4c_q09_amnt*30.42 if m4c_q09_period==8 /*day*/
replace net_profit=.a if m4c_q09_period==7|m4c_q09_period==9|m4c_q09_period==0 /*contract or don't know*/
label var net_profit "Net monthly profit from business" 
	
****************************************************************************************************************************
*HOURLY LABOR earnings             
****************************************************************************************************************************
*NUMBER OF HOURS WORKED LAST WEEK
	/*NOTE THAT SOME WORKERS REPORT HAVING NOT WORKED DURING THE LAST WEEK. THESE OBSERVATIONS ARE CHANGED TO MISSING*/
	gen hours =  m4b_q07_1 if m4b_q01_1==m4c_q01_code
	replace hours = m4b_q07_2 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_2  /*For ppl whose main 
																		occupation was listed second*/
	replace hours = m4b_q07_3 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_3  /*For ppl whose main occupation 
																		was listed third*/
	replace hours = m4b_q07_4 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_4  /*For ppl whose main occupation 
																			was listed fourth*/																	
	label var hours "Number of hours worked last week in main occupation"	
	
	gen hours_d =  m4b_q06_1 if m4b_q01_1==m4c_q01_code
	replace hours_d = m4b_q06_2 if m4b_q01_1!=m4c_q01_code &  m4c_q01_code==m4b_q01_2  /*For ppl whose main 
																		occupation was listed second*/
	replace hours_d = m4b_q06_3 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_3  /*For ppl whose main occupation 
																		was listed third*/
	replace hours_d = m4b_q06_4 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_4  /*For ppl whose main occupation 
																			was listed fourth*/			
	label var hours_d "Average number of hours worked daily in main occupation"																			
	
*HOURLY LABOR earnings 
	/*NOTES: 1. Assume that "last week" was a typical workweek. 
			 2. Use 4.35 as # of weeks in one month, 21.7 as # of week days in a month.
			 3. Assume net profits are not shared with other investors.
			 4. earningss with "other" pay periods have to be computed by hand. Some of these cannot
			   be computed, however, as they do not correspond to time periods per se or are not specified.*/
	
	gen     earnings_h = m4c_q25/hours/4.35 if m4c_q26==1   				/*earnings for wage earners, 1 month*/
	replace earnings_h = m4c_q25/hours/2.17 if m4c_q26==2 				/*earnings for wage earners,  2 weeks*/
	replace earnings_h = m4c_q25/hours   if m4c_q26==3 				    /*earnings for wage earners,  1 week*/
	replace earnings_h = m4c_q25/hours_d  if m4c_q26==4     			    /*earnings for wage earners, 1 day*/
	replace earnings_h = m4c_q27/hours/4.35 if m4c_q28==1   				/*earnings for self-employed, 1 month*/
	replace earnings_h = m4c_q27/hours/2.17 if m4c_q28==2 				/*earnings for self-employed,  2 weeks*/
	replace earnings_h = m4c_q27/hours   if m4c_q28==3 				    /*earnings for self-employed,  1 week*/
	replace earnings_h = m4c_q27/hours_d  if m4c_q28==4     			    /*earnings for self-employed, 1 day*/
	replace earnings_h=. 				if m4c_q25==92|m4c_q27==92 			/*Don't report earnings*/
	replace earnings_h=. 				if m4c_q26==92|m4c_q28==9|m4c_q26==9/*Don't report pay period*/
	replace earnings_h=. 				if hours==. 						/*Don't have info. on no. of hours*/
	label var earnings_h "Hourly labor earnings" 
	notes earnings_h: earnings for wage earners is net of taxes and benefits. earnings for self-employed is gross.  
	notes earnings_h: Corresponds to main occupation. 



/*Calcuate hourly earnings for people who specify a different pay period*/
*******
*Yunnan: Four people report a different pay period but it is not specified in the survey.
*Laos: No one reports a different pay period.
*Vietnam: It is indecipherable.
************
*Sri Lanka
***********
if country=="Sri Lanka" {
	replace earnings_h = m4c_q27/hours_d/2  if m4c_q28==10   /*earnings for self-employed, 2 days*/
}
**********
*Bolivia
*********
if country=="Bolivia" {
	replace earnings_h= m4c_q25/hours/1.45 if m4c_q26_other=="3 SEMANAS" 
	replace earnings_h= m4c_q25/hours/17.4 if m4c_q26_other=="4 MESES" 
	replace earnings_h= m4c_q25/hours/26.1 if m4c_q26_other=="6 MESES"
}


gen ln_earnings_h=log(earnings_h + 0.0000000000000000000001)
label var ln_earnings_h "Log of hourly earnings" 


*UNDEREMPLOYED 
egen total_hours_week= rsum( m4b_q07_1 m4b_q07_2 m4b_q07_3 m4b_q07_4)
gen underemp=1 if m4b_q09==1 & total_hours_week<35
replace underemp=0 if m4b_q09==2 
replace underemp=0 if total_hours_week>=35 & m4b_q09==1 & total_hours_week<.
label define underemp 0 "Not underemployed"  1 "Underemployed", replace 
label values underemp underemp
label var underemp "Underemployed"
notes underemp: Refers to working under 35 hours/week and wanting to work more hours for the same pay.
label var total_hours_week "Total hours worked during the week, all jobs"

*SOURCE OF FUNDS (FOR SELF-EMPLOYED)
recode m4c_q07 (1=1) (2=1) (3=1) (4=1) (5=0) (6=0) (7=0)(8=0) (9=1)  (10=0) (99=.), gen(source_funds)
replace source_funds=0 if source_funds>10 & source_funds<99
label var source_funds "Source of funds for starting business" 
label define source_funds 1 "Used family money" 0 "Did not use family money", replace
label values source_funds source_funds

*SIZE OF BUSINESS AT START
gen business_size=1 if m4c_q08==1
replace business_size=0 if m4c_q08>1 & m4c_q08<.
label var business_size "Size of business at start"
label define business_size 1 "One person" 0 "More than 1 person", replace
label values business_size business_size


**************************************************** END OF LABOR MARKET SECTION ****************************************************


***********************************************************************************************************************************************
*********************************************************     EDUCATION VARIABLES     *********************************************************
***********************************************************************************************************************************************

*ece (don't know's=missing)
gen ece=1 if m2_q01==1
replace ece=0 if m2_q01==2
*certification not awarded by a formal education institution
gen certificate=0 
if country!="Colombia" {
	replace certificate=1 if m2_q18==1 | m2_q05==1		/* There is no question 18 in the Colombian Q */
}
if country=="Colombia" {
	replace certificate=1 if m2_q05==1
}
*currently attending
gen current=1 if m2_q20==1
replace current=0 if  m2_q20==2
replace current=0 if m2_q02==2
*dropout
gen dropout=1 if m2_q24==1
replace dropout=0 if m2_q24==2
replace dropout=0 if current==1 /*If currently attending, don't answer this question*/
*interrupt
gen interrupt=1 if m2_q37==1
replace interrupt=0 if m2_q37==2
*training
gen training=1 if m2_q39==1
replace training=0 if m2_q39==2
*apprenticeship
gen apprenticeship=1 if m2_q41==1
replace apprenticeship=0 if m2_q41==2
*age started first grade
gen late_first_grade=1 if m2_q07>=8 & m2_q07<.
replace late_first_grade=0 if m2_q07<8
label var late_first_grade "Started first grade at age 8 or older"
*type of school attended
gen school_type = 1 if m2_q12==1
replace school_type=2 if m2_q12==2|m2_q12==3
replace school_type=3 if m2_q12==4|m2_q12==5|m2_q12==9
label define school_type 1 "Public" 2 "Private" 3 "Other"
label values school_type school_type
label var school_type "Type of school attended"  
*Age started school
gen age_start=m2_q07
recode age_start (92=.) (99=.)
label var age_start "Age started first grade" 


****************************************** EDUCATION LEVELS AND FIELD ******************************************
**************************** COUNTRY BY COUNTRY AS MODULE 2 IS COUNTRY-SPECIFIC ********************************

/**** BOLIVIA ****/
if country=="Bolivia" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 A" 6 "ISCED 4 Voc" 7 "ISCED 4 A" 8 "ISCED 5 Voc" 9 "ISCED 5 A & 6", replace

		/*LABL: The following are the labels for m2_q08, m2_q15, m2_q21, m2_q26
           1 no formal education or below (isced 1)
           2 primary education (first 6 years) (isced 1)
           3 primary education  - general education (last 2 years) (isced
           4 secondary education  - general education (4 years) (isced 3a
           5 secondary education  - technical education (4 years) (isced 
           6 pre college courses - general education (< 1 year) (isced 4a
           7 courses in technical middle institutes/ normal school (isced
           8 courses in technical higher institutes / normal school (isce
           9 courses in academy in higher normal school  (isced 5a)
          10 technical career to college level (3 - 4 years) (isced 5b) 
          11 college degree (5 years ) (isced 5a)
          12 major/ post graduated diploma/ magister degree (isced 5a)
          13 phd (4 years) (isced 6)
          99 dont know*/
*NEED TO DECIDE WHAT TO DO ABOUT 4A 
*highest level completed with vocation distinction (ISCED_v)
recode m2_q08 (1=0) (2=1) (3=3) (4=5) (5=4) (6=7) (7=6) (8=8) (9=9) (10=8) (11=9) (12=9) (13=9), gen(ISCED_v)
recode m2_q15 (1=0) (2=1) (3=3) (4=5) (5=4) (6=5) (7=6) (8=8) (9=9) (10=8) (11=9) (12=9) (13=9), gen(other_v)
replace ISCED_v=other_v if other_v>ISCED_v & other_v<. /*According to Giovanna, it is necessary to use m2_q15 to 
																	calculate highest level of edcuation completed*/

replace ISCED_v=0 if m2_q02==2  						 /*Did not attend school*/



*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5), gen(ISCED) /*4A is grouped with 3 because it (pre-university 6 month course) is not really 4A*/


**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p) /*here 4A hasn't been grouped with 3*/
replace ISCED_p=6 if m2_q08==11 /*Bachelor's degree*/
replace ISCED_p=7 if m2_q08==12 /*Master's degree*/
replace ISCED_p=8 if m2_q08==13 /*PhD degree*/ 
replace ISCED_p=9 if m2_q08<. & ISCED_p==.
replace ISCED_p=10 if m2_q08==. & ISCED_p==. 
notes  ISCED: People who have attended pre-university courses are grouped in ISCED 3. 

*current attending level
recode m2_q21 (1=0) (2=1) (3=2) (4=5) (5=4) (6=7) (7=6) (8=8) (9=9) (10=8) (11=9) (12=9) (13=9), gen(current_ISCED_v) 
recode m2_q21 (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=6) (10=5) (11=6) (12=7) (13=8), gen(current_ISCED_p)
recode m2_q21 (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=5) (10=5) (11=5) (12=5) (13=5), gen(current_ISCED)
  
*level before dropout
recode m2_q26 (1=0) (2=1) (3=2) (4=5) (5=4) (6=7) (7=6) (8=8) (9=9) (10=8) (11=9) (12=9) (13=9), gen(dropout_ISCED_v) 
recode m2_q26 (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=6) (10=5) (11=6) (12=7) (13=8), gen(dropout_ISCED_p)
recode m2_q26 (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=5) (10=5) (11=5) (12=5) (13=5), gen(dropout_ISCED)

gen highest=m2_q08
recode highest (9=10) (10=9)
gen highest2=m2_q15
recode highest2 (9=10) (10=9)
gen hgsteduc=max(highest, highest2)
recode hgsteduc (9=10) (10=9)
gen hgstcurrent=m2_q21
recode hgstcurrent (9=10) (10=9)
gen hgstdrop=m2_q26
recode hgstdrop (9=10) (10=9)

*NUMBER OF YEARS OF EDUCATION (GP & TR)
gen years_educ=0 if m2_q02==2 /*No formal education*/
replace years_educ= m2_q08c if hgsteduc==1 /*Below primary, use highest grade attended*/
replace years_educ=6 if hgsteduc==2  /*Primary, first 6 years ISCED 1*/
replace years_educ=8 if hgsteduc==3  /*Primary, first 8 years ISCED 2*/
replace years_educ=12 if hgsteduc==4  /*Secondary general ISCED 3*/
replace years_educ=12 if hgsteduc==5 /*Secondary vocational ISCED 3*/
replace years_educ=12.5 if hgsteduc==6  /*Less than one year of pre-university*/
replace years_educ=11 if hgsteduc==7   /*this level is UP to 3 years technical middle institute (could be just one)*/
replace years_educ=15 if hgsteduc==8  /*this level is UP to 3 years (could be less)*/
replace years_educ=17 if hgsteduc==9  /*this level is UP to 3 years (could be less)*/
replace years_educ=16 if hgsteduc==10 /*This level could be 3 or 4 years*/
replace years_educ=17 if hgsteduc==11 /*Could be 4 or 5 years*/
replace years_educ=19 if hgsteduc==12 /*Could be 1 to 2 years*/
replace years_educ=23 if hgsteduc==13  /*Four years PhD*/
label var years_educ "Years of education corresponding to highest level of education completed"

  /*  Following are the labels for m2_q08n
  		   9 dont know
          11 none
          12 literacy course
          13 preschool education
          14 basic (1 to 5 years)
          15 intermediate (1 and 3 years)
          16 medium (1 to 4 years)
          17 primary
          18 secondary
          19 adult basic education (abe)
          20 education center adult mean (cema)
          21 normal
          22 state university (ba)
          23 private univesidad (bs)
          24 graduate
          25 technical university
          26 technical institute
          27 institutes of military and police training
          28 other courses
          29 preuniversity*/

*highest field of study (combine general and vocational)
*the variable highest_field does not have a label*
*highest field corresponds to highest education level corrected for m2_q15*
recode hgsteduc (9=10) (10=9)

gen highest_field_1=m2_q09_1 
replace highest_field_1=m2_q11_1 if missing( highest_field_1)
replace highest_field_1=. if hgsteduc>highest & hgsteduc~=.
replace highest_field_1=m2_q16 if m2_q16~=. & hgsteduc==highest2 & hgsteduc>highest
replace highest_field_1=m2_q17 if m2_q17~=. & hgsteduc==highest2 & hgsteduc>highest

gen highest_field_2=m2_q09_2
replace highest_field_2=m2_q11_2 if missing( highest_field_2)
replace highest_field_2=. if hgsteduc>highest & hgsteduc~=.

drop highest highest2 hgsteduc


*number of degrees *PENDING
/*gen numb_deg_same_level=1 if highest_field_1<. & highest_field_2==.
replace numb_deg_same_level=2 if highest_field_2<.
replace numb_deg_same_level=3 if m2_q15

gen numb_deg_lower_level=1 if m*/
*current attending field 
gen current_field=m2_q22 
replace current_field=m2_q23 if missing(current_field) 

*field before dropout
gen dropout_field=m2_q27 
replace dropout_field=m2_q28 if missing(m2_q27 )

*training field
gen training_field_1=m2_q40_1 
gen training_field_2=m2_q40_2

*EDUCATION LEVEL NEEDED FOR JOB
*LEVEL 4A is not meant to lead to the labor market. It is thus strange that some people say that pre-university courses (6)
*are required for the job. We consider this ISCED 3, as is the case when definining ISCED levels. 
recode m5b_q22 (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=4) (8=5) (9=5) (10=5) (11=5) (12=5) (13=6), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q22==99
label var ISCED_needed "Education level need for the job"
notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13==3|m2_q13==9

drop hgstcurrent hgstdrop
}

/**** END OF BOLIVIA ****/


/**** COLOMBIA ****/
if country=="Colombia" {

**** EDUCATION LEVELS AND FIELD*************
label define educ_ISCED 0 "None or below primary" 1 "Complete primary" 2 "Complete lower secondary"	3 "Complete upper secondary"	4 "Technical/technological"	5 "University and above" , replace
*highest level completed with vocation distinction (ISCED_v)
gen ISCED_v=.
replace  ISCED_v=0 if m2_q02==2  				 /*Did not attend school*/
replace  ISCED_v=0 if m2_q08==2  		         /*ISCED 0*/
replace  ISCED_v=0 if m2_q08==3 & m2_q08_g<5  	/*ISCED 0*/
replace  ISCED_v=1 if m2_q08==3  & m2_q08_g==5  	/*ISCED 1*/
replace  ISCED_v=1 if m2_q08==4 & m2_q08_g<4    /*ISCED 1*/
replace  ISCED_v=3 if m2_q08==4 & m2_q08_g==4  /*ISCED 2 GEN*/
replace  ISCED_v=3 if m2_q08==5 & m2_q08_g<2  /*ISCED 2 GEN*/ 	
replace  ISCED_v=4 if m2_q08a==3|m2_q08a==4  	 /*ISCED 3 VOC*/
replace  ISCED_v=5 if m2_q08a==2              	/*ISCED 3 GEN*/
replace  ISCED_v=8 if m2_q08a>=5 & m2_q08a<=6    	/*ISCED 5 VOC*/
replace  ISCED_v=9 if m2_q08a>=7 & m2_q08a<=10  	/*ISCED 5 A & 6*/
replace  ISCED_v=5 if hhn==34 & cluster==46634 	/*ISCED 3 GEN*/
replace  ISCED_v=5 if hhn==3 & cluster==46803 	/*ISCED 3 GEN*/
replace  ISCED_v=3 if hhn==21 & cluster==38521 	/*ISCED 2 GEN*/
replace  ISCED_v=3 if hhn==12 & cluster==43612 	/*ISCED 2 GEN*/

lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 Gen" 6 "ISCED 4 Voc" 7 "ISCED 4 Gen" 8 "ISCED 5 Voc" 9 "ISCED 5 Gen & 6", replace				
*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5), gen(ISCED) 
replace ISCED=3 if cluster==30506 
replace ISCED=3 if cluster==46707 


*Highest level completed vocational or not
gen educ_voc=. 
replace educ_voc=1 if (ISCED_v==2)
replace educ_voc=1 if (ISCED_v==4)
replace educ_voc=1 if (ISCED_v==6)
replace educ_voc=1 if (ISCED_v==8)

replace educ_voc=3 if (ISCED_v==0|ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3)
replace educ_voc=3 if (ISCED_v==5)
replace educ_voc=3 if (ISCED_v==7)
replace educ_voc=3 if (ISCED_v==9)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p) /*here 4A hasn't been grouped with 3*/
replace ISCED_p=6 if m2_q08a==7 /*Bachelor's */
*replace ISCED_p=11 if m2_q08a==8 /*Specialization, cf. NM's June 27, 2013 email*/
replace ISCED_p=6 if m2_q08a==8	/* Assigned "Specialization to Bachelor's because according to NM's email it is not considered as a Master's */
replace ISCED_p=7 if m2_q08a==9 /*Master's degree*/
replace ISCED_p=8 if m2_q08a==10 /*PhD degree*/ 
replace ISCED_p=3 if ISCED==3 /*currently in technical/technological but claim to have no degree. Assume ISCED 3*/
replace ISCED_p=9 if m2_q08<. & ISCED_p==. /*Don't know*/
replace ISCED_p=10 if m2_q08==. & ISCED_p==. /*Refuse*/

lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 11 "ISCED 5A, specialization" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
*current attending level
 gen current_ISCED_v=.
 replace current_ISCED_v =1 if m2_q21==1 					/*ISCED 1*/
 replace current_ISCED_v =3 if m2_q21==2 					/*ISCED 2 Gen*/
 replace current_ISCED_v =4 if m2_q21a==3|m2_q21a==4 		/*ISCED 3 Voc*/
 replace current_ISCED_v =4 if m2_q21a==99 & m2_q21_g==3 	/*Person who is in third grade of media must be getting vocational degree (otherwise would have alrady graduated*/
 replace current_ISCED_v =5 if m2_q21a==2					 /*ISCED 3 Gen*/
 replace current_ISCED_v =8 if m2_q21a==5|m2_q21a==6 		/*ISCED 5 Voc*/
 replace current_ISCED_v =9 if m2_q21a>=7 & m2_q21a<99 		/*ISCED 5 Gen & 6*/
 
recode current_ISCED_v  (1=1) (2=2) (3=2) (4=3) (5=3) (8=5) (9=.) (10=.), gen(current_ISCED_p) 
replace current_ISCED_p=6 if m2_q21a==7 /*Bachelor's*/
replace current_ISCED_p=11 if m2_q21a==8 /*Specialization*/ 
replace current_ISCED_p=7 if m2_q21a==9 /*Master's degree*/
replace current_ISCED_p=8 if m2_q21a==10 /*PhD degree*/ 

recode current_ISCED_p (6=5) (7=5) (8=5), gen(current_ISCED)
  
*level before dropout
gen	dropout_ISCED_v=.  /*NOTE: It isn't possible to differentiate between general and vocational upper secondary; therefore, don't have dropout_ISCED_v
for Colombia*/
 gen dropout_ISCED_p2=.
 replace dropout_ISCED_p2 =1 if m2_q26_1==1 /*ISCED 1*/
 replace dropout_ISCED_p2 =2 if m2_q26_1==2 /*ISCED 2*/
 replace dropout_ISCED_p2 =3 if m2_q26_1==3 /*ISCED 3A-B*/
 replace dropout_ISCED_p2 =5 if m2_q26_1==4 /*ISCED 5B*/
 replace dropout_ISCED_p2 = 6 if m2_q26_1==5      /*ISCED 5A, bachelor*/
 replace dropout_ISCED_p2 =7 if m2_q26_1==6 /*ISCED 5A specialization, master & ISCED 6*/
 replace dropout_ISCED_p2 =9 if m2_q26_1==99 /*DK*/
 
 lab define dropout_ISCED_p2 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A specialization, master & ISCED 6"  9 "DK", replace

recode dropout_ISCED_p2 (1=1) (2=2) (3=3) (5=5) (6=4) (8=5) (9=5) (9=5) (10=5) (11=5) (12=5) (13=5), gen(dropout_ISCED)
drop dropout_ISCED_p2
*CHANGE EDUCATION VARIABLES TO MISSING IF THERE ARE INCONSISTENCIES IN DATA
replace ISCED_v=. if m2_q08



*NUMBER OF YEARS OF EDUCATION *PENDING*
gen years_educ=.
replace  years_educ=0 if m2_q02==2 /*No formal education*/
replace  years_educ=0 if m2_q08==2 /*Preschool: 0 years*/
replace years_educ= m2_q08_g if m2_q08==3 /*Use grade*/
replace years_educ=5 + m2_q08_g if m2_q08==4  /*Lower secondary*/
replace years_educ=9  + m2_q08_g if m2_q08==5 /*Upper secondary*/
replace years_educ=11 + (m2_q08_g/2) if m2_q08==6   /*Technical/technological (standard upper secondary is 11 years)*/
replace years_educ=11 + (m2_q08_g/2) if m2_q08==7   /*University (standard upper secondary is 11 years)*/
replace years_educ=16 + (m2_q08_g/2) if m2_q08==8   /*University (standard upper secondary is 11 years)*/
replace years_educ=20 if m2_q08a==10 /*Assume person with PhD is referring to 4 years of education, not four semesters*/

label define M2_Q08 2	Preschool ///
	3	"Primary (grades 1 to 5)" ///
	4	"Lower Secondary (grades 6 to 9)" ///
	5	"Upper Secondary (grades 10 to 13)" ///
	6	"Technician or technological" ///
	7	"University"  ///
	8	"Graduate school"  ///
	99	"DK/RF" , modify

 label define M2_Q08A    1 None ///
           2 "Classic high school diploma" ///
           3 "Technical high school diploma" ///
           4 "Teaching H.S. diploma (Bachiller normalista)" ///
           5 "Professional Technician" ///
           6 "Technological" ///
           7 "Bachelor's" ///
           8 "Specialization" ///
           9 "Master's" ///
          10 "PhD" ///
          99 "DK/RF", modify

*highest field of study (combine general and vocational)
gen highest_field_1=m2_q09_1
replace highest_field_1=m2_q11_1 if missing( highest_field_1)
gen highest_field_2=m2_q09_2
replace highest_field_2=m2_q11_2 if missing( highest_field_2)

*number of degrees *PENDING
/*gen numb_deg_same_level=1 if highest_field_1<. & highest_field_2==.
replace numb_deg_same_level=2 if highest_field_2<.
replace numb_deg_same_level=3 if m2_q15
gen numb_deg_lower_level=1 if m*/

*current attending filed 
gen current_field=m2_q22 
replace current_field=. if m2_q22==88
replace current_field=m2_q23 if missing(current_field) 
replace current_field=. if m2_q23==88

*field before dropout
gen dropout_field=m2_q27 
replace dropout_field=m2_q28 if missing(m2_q27 )

*training field
gen training_field_1=m2_q40_1 
gen training_field_2=m2_q40_2

*EDUCATION LEVEL NEEDED FOR JOB
    /*     1 No formal education
           2 Preschool
           3 Basic Primary (1st to 5th grade)
           4 Basic Secondary (6th to 9th grade)
           5 Middle School (10th to 13th grade)
           6 Technician or technological
           7 Superior or University
           8 Postgrad or PhD
          99 Dont know*/

recode m5b_q22 (1=0) (2=0) (3=1) (4=2) (5=3) (6=5) (7=5)  (8=7), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q22==99
label var ISCED_needed "Education level need for the job"
notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==7 & ISCED_needed==7  /*Assume individual has the required graduate degree*/
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==7 /*Assume individual has the required graduate degree*/
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13==3|m2_q13==9
}
/**** END OF COLOMBIA ****/


/**** LAOS ****/
if country=="Laos" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define _ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 B" 3 "ISCED 2 A" 4 "ISCED 3 B" ///
					5 "ISCED 3 A" 6 "ISCED 4 B" 7 "ISCED 4 A" 8 "ISCED 5 B" 9 "ISCED 5 A & 6", replace
*highest education levels completed
gen ISCED_v=.
replace ISCED_v=0 if m2_q02==2  				/*NO SCHOOLING*/
replace ISCED_v=0 if m2_q08==1 					/*LESS THAN PRIMARY*/
replace ISCED_v=1 if m2_q08==2   				/*PRIMARY*/
replace ISCED_v=2 if m2_q08==2 &  m2_q08a==5 	/*VOCATIONAL LOWER SECONDARY (COMPLETE VOCATIONAL LOW DIPLOMA)*/
replace ISCED_v=3 if m2_q08==3                  /*GENERAL LOWER SECONDARY*/
replace ISCED_v=4 if m2_q08==3 & m2_q08a==5  	 /*VOCATIONAL UPPER SECONDARY (COMPLETE VOCATIONAL LOW DIPLOMA)*/
replace ISCED_v=5 if  m2_q08==4   				/*GENERAL UPPER SECONDARY*/
replace ISCED_v=6 if m2_q08a==6  				/*ISCED 4B, VOCATIONAL (COMPLETE MIDDLE DIPLOMA*/
												/*ISCED 4A DOES NOT EXIST*/
replace ISCED_v=8 if m2_q08a==7 				/*ISCED 5B COMPLETE HIGH DIPLOMA*/
replace ISCED_v=9 if m2_q08a==8 |m2_q08a==9  	/*COMPLETE BACHELORS, MASTERS*/
replace ISCED_v=9 if m2_q08a==10   				/*COMPLETE PHD*/
*Highest level according to m2_q15
recode m2_q15 (1=.)(5=4) (6=6) (7=8) (8=9) (9=9) (10=9), gen(other_v) /*SEVEN OBSERVATIONS ANSWER "1" but they don't actually have an additional certificate*/
gen ISCED_vo=ISCED_v
replace ISCED_v=other_v if other_v>ISCED_v & other_v<. /*Correct case in which person should have ISCED 4 instead of ISCED 1 according to m2_q15*/

*highest ISCED level
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=5), gen(ISCED)

**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree", replace
label 	var	educ_voc	"Highest education level completed is vocational/general"
label values educ_voc educ_voc

*HIGHEST ISCED, detailed
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p)
replace ISCED_p=6 if m2_q08a==8 /*Bachelor's degree*/
replace ISCED_p=7 if m2_q08a==9 /*Master's degree*/
replace ISCED_p=8 if m2_q08a==10 /*PhD degree*/ 
replace ISCED_p=9 if m2_q08<. & ISCED_p==.
replace ISCED_p=10 if m2_q08==. & ISCED_p==. 
replace ISCED_p=6 if ISCED_p==9 & m2_q15==8 /*correct for higher degree indicated in q15*/
replace ISCED_p=7 if ISCED_p==9 & m2_q15==9 /*correct for higher degree indicated in q15*/

*highest level_field of study (combine general and vocational)
 
gen highest_field_1=m2_q09_1 
replace highest_field_1=m2_q11_1 if missing(highest_field_1)
replace highest_field_1=m2_q16 if other_v>ISCED_vo & other_v~=. & m2_q16~=.
replace highest_field_1=m2_q17 if other_v>ISCED_vo & other_v~=. & m2_q17~=.

gen highest_field_2= m2_q09_2 
replace highest_field_2= m2_q11_2 if missing(highest_field_2)

*YEARS OF EDUCATION
gen years_educ=0 if m2_q02==2 /*zero years if no schooling*/
replace years_educ=2.5 if m2_q08==1  /*Half # years of primary if did not complete primary*/
replace years_educ= 5 if m2_q08==2 /*ISCED 1*/
replace years_educ= 9 if m2_q08==3 /*ISCED 2A*/
replace years_educ= 9 if ISCED==2 /*LOWER SECONDARY*/
replace years_educ= 12 if ISCED==3  /*ISCED 3*/
replace years_educ= 15 if ISCED_v==6 /*4B - Middle diploma*/ 
replace years_educ= 15 if ISCED_p==5 /*ISCED 5B COMPLETE HIGH - mode is 3 years to complete*/
replace years_educ= 17 if ISCED_p==6 /*Bachelors - assume 5 years to complete*/
replace years_educ= 19 if ISCED_p==6 & highest_field_1==15 /*Bachelors medicine takes 7 years*/
replace years_educ= 19 if ISCED_p==7 /* Masters - 2 years to complete*/
replace years_educ= 23 if ISCED_p==8 /*ISCED 6 - assume 4 years to complete*/

label var years_educ "Years of education corresponding to highest level of education completed"


*current attending level
gen current_ISCED=.
replace current_ISCED=0 if m2_q21==1
replace current_ISCED=1 if m2_q21==2
replace current_ISCED=2 if m2_q21==3 
replace current_ISCED=2 if m2_q08==2 &  m2_q21==5
replace current_ISCED=3 if  m2_q21==4 
replace current_ISCED=3 if m2_q08==3 & m2_q21==5
replace current_ISCED=4 if m2_q21==6
replace current_ISCED=5 if m2_q21==7 |m2_q21==8 |m2_q21==9
replace current_ISCED=5 if m2_q21==10

gen current_ISCED_v=.
replace current_ISCED_v=0 if m2_q21==1
replace current_ISCED_v=1 if m2_q21==2
replace current_ISCED_v=3 if m2_q21==3 
replace current_ISCED_v=2 if m2_q08==2 &  m2_q21==5
replace current_ISCED_v=5 if  m2_q21==4 
replace current_ISCED_v=4 if m2_q08==3 & m2_q21==5
replace current_ISCED_v=7 if m2_q21==6
replace current_ISCED_v=8 if m2_q21==7 
replace current_ISCED_v=9 if m2_q21==8 |m2_q21==9
replace current_ISCED_v=9 if m2_q21==10

*current attending filed 
gen current_field=m2_q22_1
replace current_field= m2_q23 if missing(current_field) 

*level before dropout
gen dropout_ISCED=.
replace dropout_ISCED=0 if m2_q26_1==1
replace dropout_ISCED=1 if m2_q26_1==2
replace dropout_ISCED=2 if m2_q26_1==3 
replace dropout_ISCED=2 if m2_q08==2 &  m2_q26_1==5
replace dropout_ISCED=3 if  m2_q26_1==4 
replace dropout_ISCED=3 if m2_q08==3 & m2_q26_1==5
replace dropout_ISCED=4 if m2_q26_1==6
replace dropout_ISCED=5 if m2_q26_1==7 |m2_q26_1==8 |m2_q26_1==9
replace dropout_ISCED=5 if m2_q26_1==10

gen dropout_ISCED_v=.
replace dropout_ISCED_v=0 if m2_q26_1==1
replace dropout_ISCED_v=1 if m2_q26_1==2
replace dropout_ISCED_v=3 if m2_q26_1==3 
replace dropout_ISCED_v=2 if m2_q08==2 &  m2_q26_1==5
replace dropout_ISCED_v=5 if m2_q26_1==4 
replace dropout_ISCED_v=4 if m2_q08==3 & m2_q26_1==5
replace dropout_ISCED_v=7 if m2_q26_1==6
replace dropout_ISCED_v=8 if m2_q26_1==7 
replace dropout_ISCED_v=9 if m2_q26_1==8 |m2_q26_1==9
replace dropout_ISCED_v=9 if m2_q26_1==10

*field before dropout
gen dropout_field=m2_q27  
replace dropout_field=m2_q28 if missing(dropout_field)

*training field
gen training_field_1=m2_q40_1 
gen training_field_2=m2_q40_2

*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q22 (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=5) (8=5)(9=5)(10=5), gen(ISCED_needed) 
replace ISCED_needed=. if m5b_q22==99
label var ISCED_needed "Education level need for the job"
notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job*/
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13>2 & m2_q13<.

drop ISCED_vo
}
/**** END OF LAOS ****/


/**** SRI LANKA ****/
if country=="Sri Lanka" {

lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define _ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 Gen" 6 "ISCED 4 Voc" 7 "ISCED 4 Gen" 8 "ISCED 5 Voc" 9 "ISCED 5 Gen & 6", replace
					
*highest level completed /*BASED ON JINENDRA's EMAIL AND ON THE LEVEL LISTED */
 gen    ISCED=0 if m2_q02==2				/*NONE OR BELOW PRIMARY*/
replace ISCED=0 if m2_q08_grade<=4 & m2_q08_level==1  	/*NONE OR BELOW PRIMARY*/
replace ISCED=1 if m2_q08_grade==5 &  m2_q08_level==1 	/*PRIMARY (completed 5 years of primary)*/
replace ISCED=1 if m2_q08_grade<8 & m2_q08_level==2 	/*PRIMARY (started secondary but did not complete)*/
replace ISCED=2 if m2_q08_grade==8 & m2_q08_level==2 	/*LOWER SECONDARY (completed grade 8)*/
replace ISCED=2 if m2_q08_grade<10 & m2_q08_level==3 & m2_q08_1==6	/*LOWER SECONDARY (started upper secondary but did not complete)*/
replace ISCED=2 if m2_q08_grade==10 & m2_q08_level==3 & m2_q08_1==6	/*LOWER SECONDARY (did not pass O'Level)*/
replace ISCED=2 if m2_q08_grade==11 & m2_q08_level==3 & m2_q08_1==6	/*LOWER SECONDARY (did not pass O'Level)*/
replace ISCED=2 if m2_q08_grade>=11 & m2_q08_grade<=12 & m2_q17_2==. & m2_q08_1==6 /*LOWER SEC. did not pass O'Level*/

replace ISCED=3 if m2_q08_1==1							/*UPPER SECONDARY (passed O LEVEL)*/
replace ISCED=3 if m2_q08_1==2  						/*UPPER SECONDARY (senior secondary)*/
replace ISCED=3 if m2_q17_2==11|m2_q17_2==12 			/*UPPER SEC. Certificate or technical education diploma*/
replace ISCED=3 if (m2_q15==1|m2_q15==2 )				/*correct for additional diploma question*/

replace ISCED=5 if m2_q08_1==3  						/*TERTIARY, BACHELORS*/
replace ISCED=5 if m2_q15==3  							/*TERTIARY, BACHELORS*/
replace ISCED=5 if m2_q08_1==4|m2_q08_1==5				/*TERTIARY, MASTERS & PHD*/
replace ISCED=5 if m2_q17_2==13|m2_q17_2==14			/*VOCATIONAL TERTIARY*/

gen ISCED_v = ISCED 
recode ISCED_v (2=3) (3=5)
replace ISCED_v=4 if m2_q17_2==11|m2_q17_2==12 /*Certificate or technical education diploma*/
replace ISCED_v=8 if m2_q17_2==13|m2_q17_2==14 /* Professional qualification or votational technology degree*/
replace ISCED_v=9 if m2_q08_1==4|m2_q08_1==5
replace ISCED_v=9 if m2_q08_1==3 
replace ISCED_v=9 if m2_q15==3 

**Highest level completed vocational or not
gen     educ_voc=1 if ISCED_v==4 & m2_q08_1==6 
replace educ_voc=1 if ISCED_v==8 & m2_q08_1==6 

replace educ_voc=2 if m2_q08_1==1 & ISCED_v==4 /*O LEVELS AND ISCED 3 VOC*/
replace educ_voc=2 if m2_q08_1==2 & ISCED_v==4 /*O LEVELS AND ISCED 3 VOC*/
replace educ_voc=2 if m2_q08_1>=3 & m2_q08_1<=4 & (m2_q17_2==13|m2_q17_2==14) /*BACHELOR'S/MASTER'S AND ISCED 3 VOC*/

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1|ISCED_v==3) /*None, primary, lower secondary = GENERAL*/
replace educ_voc=3 if  m2_q17_1==2

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

gen ISCED_p = ISCED_v 
replace ISCED_p=2 if ISCED_v ==3 /*ISCED 2*/
replace ISCED_p=3 if ISCED ==3 /*ISCED 3*/
replace ISCED_p=5 if ISCED_v==8 /*ISCED 5 B*/ 
replace ISCED_p=6 if m2_q08_1==3 /*Bachelor's*/
replace ISCED_p=7 if m2_q08_1==4 /*Master's*/
replace ISCED_p=7 if m2_q15==4 /*Master's*/
replace ISCED_p=8 if m2_q08_1==5 /*Phd*/
replace ISCED_p=9 if m2_q08_grade<. & ISCED_p==.
replace ISCED_p=10 if m2_q08_grade==. & ISCED_p==. 

*******************************************
*YEARS OF EDUCATION ****
gen years_educ=. 
replace years_educ=0 if m2_q02==2
replace years_educ=m2_q08_grade if ISCED==0 & years_educ==. /*did not complete primary, count grade completed*/
replace years_educ=5 if ISCED==1 /*completed primary - 5 years */
replace years_educ=8 if ISCED==2 /*completed lower secondary - 8 years*/
replace years_educ= 10 if ISCED==3 & m2_q08_1==1		/*UPPER SECONDARY (passed O LEVEL)*/
replace years_educ=12 if ISCED==3 & m2_q08_1==2  		/*UPPER SECONDARY (senior secondary)*/
replace years_educ=12 if ISCED==3 & (m2_q17_2==11|m2_q17_2==12) 			/*UPPER SEC. Certificate or technical education diploma*/
replace years_educ=10 if ISCED==3 & m2_q15==1				/*correct for additional diploma question*/
replace years_educ=12 if ISCED==3 & m2_q15==2				/*correct for additional diploma question*/
replace years_educ=16 if ISCED==5 & m2_q08_1==3  			/*TERTIARY, BACHELORS*/
replace years_educ=18 if ISCED==5 & m2_q08_1==3 & m2_q09_1==15  			/*TERTIARY, BACHELORS in medecine*/
replace years_educ=16 if ISCED==5 & m2_q15==3  							/*TERTIARY, BACHELORS*/
replace years_educ=18 if ISCED==5 & m2_q15==3 & m2_q16==15				/*TERTIARY, BACHELORS in medecine*/
replace years_educ=18 if ISCED==5 & m2_q08_1==4				/*TERTIARY, Master*/
replace years_educ=20 if ISCED==5 & m2_q08_1==5				/*TERTIARY, PHD*/
replace years_educ=15 if ISCED==5 & (m2_q17_2==13|m2_q17_2==14) & (years_educ<15 | years_educ==.)			/*VOCATIONAL TERTIARY*/
label var years_educ "Years of education corresponding to highest level of education completed"



*highest level_field of study (combine general and vocational)

gen highest_field_1=m2_q09_1
replace highest_field_1=m2_q17_3 if ISCED_v==2 | ISCED_v==4 | ISCED_v==6 | ISCED_v==8

gen highest_field_2=m2_q09_2
replace highest_field_2=m2_q17_6_2 if ISCED_v==2 | ISCED_v==4 | ISCED_v==6 | ISCED_v==8
replace highest_field_2=. if ISCED_v==8 & m2_q17_3==2 & m2_q17_4==2   

*current attending level
recode m2_q21_level (2=2) (3=3)(4=3) (6=5) (7=5) (11=3) (12=3) (13=5) (14=5), gen(current_ISCED)
recode m2_q21_level (2=3)(3=5) (4=5) (5=9) (6=9) (7=9) (11=4) (12=4) (13=8) (14=8), gen(current_ISCED_v)

*current attending filed 
gen current_field=m2_q22 
replace current_field=m2_q23 if missing(current_field) 

*level before dropout
*drop dropout_ISCED dropout_level
recode m2_q26 (2=2) (3=3)(4=3) (6=5) (7=5) (11=3) (12=3) (13=5) (14=5), gen(dropout_ISCED)
recode m2_q26 (2=3)(3=5) (4=5) (5=9) (6=9) (7=9) (11=4) (12=4) (13=8) (14=8), gen(dropout_ISCED_v)

*field before dropout
gen dropout_field=m2_q27 
replace dropout_field=m2_q28 if missing(m2_q27 )

*training field
gen training_field_1=m2_q40_1 
gen training_field_2=m2_q40_2

*EDUCATION LEVEL NEEDED FOR JOB
/*NOTE THAT SOME LEVELS HAVE NOT BEEN DEFINED YET*/
recode m5b_q22 (1=0) (2=1) (3=2) (4=2) (5=3) (6=5) (7=5) (8=5) (11=3) (12=3) (13=5)(14=5) (16=5) (99=.) (15=.) (17=.), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q22==99
label var ISCED_needed "Education level need for the job"
notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	label var ISCED_dif "Difference between education and education needed for job"

*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2|m2_q13==3	
replace school_location=3 if m2_q13>=4 & m2_q13<.


}
/**** END OF SRI LANKA ****/


/**** VIETNAM ****/
if country=="Vietnam" {
destring m2_q08_2, replace
lab define _ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
				   5 "ISCED 3 Gen" 6 "ISCED 4 Voc" 7 "ISCED 4 Gen" 8 "ISCED 5 Voc" 9 "ISCED 5 Gen & 6", replace

lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                   5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
/*m2_q08_1:
           1 primary school
           2 lower secondary school
           3 upper secondary school
           7 college
           8 university
          10 master
          11 phd
          19 no formal education or below
m2_q08a:
           3 upper secondary school
           6 college
           8 bachelor degree
           9 master degree
          10 phd degree
          19 under upper secondary school/no degree, certificate
		  
		  m2_q11b:
           4 vocational training high school UPPER SECONDARY VOCATIONAL
           5 vocational secondary education PROFESSIONAL SCHOOL
           7 vocational training college VOCATIONAL COLLEGE
          17 elementary employment ELEMENTARY VOCATIONAL
          19 no degree/certificate*/
				   				   				   

	*HIGHEST ISCED LEVELS COMPLETED
/* NATALIA'S ORIGINAL CODE CORRECTED USING LABELS FOR Q15 AS INDICATED IN DATA FILES*/
*HIGHEST ISCED*
gen general_ISCED=.
replace general_ISCED=0 if  (m2_q08_1==1 & m2_q08_2<5) | m2_q08_1==19  					/*Level 0: No formal education or incomplete primary*/
replace general_ISCED=1 if (m2_q08_1==1 & m2_q08_2==5) |  (m2_q08_1==2 & m2_q08_2<9)	/*Level 1: Complete primary school or incomplete secondary school*/
replace general_ISCED=2 if (m2_q08_1==2 & m2_q08_2==9) | (m2_q08_1==3 & m2_q08_2<12)	/*Level 2: Complete lower secondary or incomplet upper secondary*/
replace general_ISCED=2 if  (m2_q08_1==3 & m2_q08_2==12 & m2_q08a==19)					/*Level 2: Seven individuals who claims to have completed 12th grade
																							but doesn't have a upper secondary*/
replace general_ISCED=3 if (m2_q08_1==7 &  m2_q08a==19)									/*Level 3: One individual who claims to have not completed upper secondary 
																							but is currently attending college*/
replace general_ISCED=3 if m2_q08a==3													/*Level 3: Complete upper secondary, according to q8a*/
replace general_ISCED=3 if m2_q15==3 			                                        /*Level 3: Complete upper secondary, according to q15*/

replace general_ISCED=5 if m2_q08a ==6 													/*Level 5: Complete college (non-vocational), according to q8a*/
replace general_ISCED=5 if m2_q15==6													/*Correct Level for Collage non vocational */

replace general_ISCED=5 if m2_q08a==8 |m2_q08a==9|m2_q08a==10          					/*Level 5: Complete bachelor/university or master's, according to q8a*/
replace general_ISCED=5 if m2_q15==8 |m2_q15==9 | m2_q15==10							/*Level 5: COMPLETE BACHELORS, MASTERS*/

gen vocational_ISCED=.
replace vocational_ISCED=general_ISCED if m2_q11b==17 									/*Elementary vocational is based on educational levels*/
replace vocational_ISCED=3 if m2_q11b==4 | m2_q11b==5									/*Level 3: Complete vocational training high school or complete vocational ///
																						secondary education/professional school*/
replace vocational_ISCED=3 if m2_q15==4 | m2_q15==5										/*Level 3: Complete vocational training high school or complete vocational ///
																						secondary education/professional school*/

replace vocational_ISCED=4 if m2_q11b==7 												/*Level 4: Complete vocational college*/
replace vocational_ISCED=4 if m2_q15==7 												/*Level 4: Complete vocational college*/


tab  general_ISCED vocational_ISCED

gen ISCED=max(general_ISCED, vocational_ISCED)                                 /*Take the max of general and vocational ISCED*/
replace ISCED=0 if m2_q02==2													/*Level 0: No formal education*/


								   

*HIGHEST ISCED LEVELS COMPLETED
*HIGHEST ISCED*
**Highest level completed vocational or not
gen educ_voc=1 if  ISCED==vocational_ISCED

replace educ_voc=2 if general_ISCED == vocational_ISCED 

replace educ_voc=3 if vocational_ISCED==. 
replace educ_voc=3 if general_ISCED>vocational_ISCED

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc


/* Added systematic check for question 15 and corrected for labels actually used in the data files (different to those indicated in the Adapted English Q) */


*HIGHEST ISCED WITH VOCATIONAL DISTINCTION* 

gen ISCED_v= 0 if ISCED==0
replace ISCED_v=1 if ISCED==1
replace ISCED_v=2 if ISCED==2 & ISCED==vocational_ISCED
replace ISCED_v=3 if ISCED==2 & ISCED== general_ISCED
replace ISCED_v=4 if ISCED==3 & ISCED==vocational_ISCED
replace ISCED_v=5 if ISCED==3 & ISCED== general_ISCED
replace ISCED_v=6 if ISCED==4 & ISCED==vocational_ISCED
replace ISCED_v=7 if ISCED==4 & ISCED== general_ISCED
replace ISCED_v=8 if ISCED==5 & ISCED==vocational_ISCED
replace ISCED_v=9 if ISCED==5 & ISCED== general_ISCED


*HIGHEST ISCED, detailed
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p)
replace ISCED_p=5 if m2_q08a ==6 | m2_q15 ==6  /*Non-vocational college is ISCED 5*/
replace ISCED_p=6 if m2_q08a==8 /*Bachelor's degree*/
replace ISCED_p=6 if m2_q15==8 /*Bachelor's degree*/
replace ISCED_p=7 if m2_q08a==9 /*Master's degree*/
replace ISCED_p=7 if m2_q15==9 /*Master's degree*/
replace ISCED_p=8 if m2_q08a==10 /*PhD degree*/ 
replace ISCED_p=8 if m2_q15==10 /*PhD degree*/ 

replace ISCED=0 if m2_q02==2
replace ISCED_p=0 if m2_q02==2
replace ISCED_v=0 if m2_q02==2
replace ISCED_p=9 if m2_q08_2<. & ISCED_p==.
replace ISCED_p=10 if m2_q08_2==. & ISCED_p==. 
* if general and vocational degree on the same level, go with vocational degree



/* YEARS OF EDUCATION REVISED */
*YEARS OF EDUCATION
gen years_educ=0 if ISCED_v==0  /*Zero years if no edu or only preschool*/
replace years_educ=m2_q08_2 if ISCED_v==0 & m2_q08_1==1 & m2_q08_2<5 /*If some primary schooling, count the number of years completed */
replace years_educ= 5 if ISCED_v==1 /*ISCED 1: primary school completed = 5 years*/
		/* No ISCED 2 Vocational in Vietnam*/
replace years_educ= 9 if ISCED_v==3 /*ISCED 2: lower secondary general = 9 years*/
replace years_educ= 12 if ISCED_v==4  /*ISCED 3 Vocational: 3 years after lower secondary general based on document "secondary education in Vietnam"*/
replace years_educ= 12 if ISCED_v==5 /*ISCED 3 General: 3 years after lower secondary general*/
replace years_educ= 13 if ISCED_v==6 /*ISCED 4 Vocational: 4 years after ISCED 2 based on document "secondary education in Vietnam"*/
replace years_educ= 15 if ISCED_p==5 /*ISCED 5 College: 3 years after upper secondary general*/
replace years_educ= 16 if ISCED_p==6 /*ISCED 5 Bachelor's: most do 4 years after upper secondary general*/
replace years_educ= 18 if ISCED_p==6 & m2_q08_2==6 /*ISCED 5 Bachelor's: some do a specialization not counted as masters (takes 2 years to complete)*/
replace years_educ= 18 if ISCED_p==7 /*ISCED 5 Master's: 2 years after Bachelor's*/
replace years_educ= 20 if ISCED_p==8 /*ISCED 6 PhD: min 2 years after Master's*/
label var years_educ "Years of education corresponding to highest level of education completed"


/*m2_q08_1:
           1 primary school
           2 lower secondary school
           3 upper secondary school
           7 college
           8 university
          10 master
          11 phd
          19 no formal education or below*/
*field 
*highest level_field of study (combine general and vocational, if on both level, go with vocational)
*NOT CORRECTED FOR M2Q15*
gen highest_field_1=m2_q09_1 if ISCED==general_ISCED
replace highest_field_1=m2_q11d_1 if ISCED==vocational_ISCED & vocational_ISCED~=. & vocational_ISCED>general_ISCED
  
gen highest_field_2=m2_q09_2 if ISCED_v==1 | ISCED_v==3 | ISCED_v==5 | ISCED_v==7 |ISCED_v==9
replace highest_field_2=m2_q11d_2 if ISCED_v==2 | ISCED_v==4 | ISCED_v==6 | ISCED_v==8

*current attending level
recode m2_q21_1 (1=1)(2=2) (3=3) (4=3) (5=3) (6=4) (7=4) (8=5) (9=5) (10=5), gen(current_ISCED)
recode m2_q21_1 (1=1)(2=3) (3=5) (4=4) (5=4) (6=7) (7=6) (8=9) (9=9) (10=9), gen(current_ISCED_v)

*current attending filed 
gen current_field=m2_q22
replace current_field=m2_q23 if missing(m2_q22)

*level before dropout
recode m2_q26 (1=1) (2=2) (3=3) (4=3) (5=3) (6=4) (7=4) (8=5) (9=5) (10=5), gen(dropout_ISCED)
recode m2_q26 (1=1)(2=3) (3=5) (4=4) (5=4) (6=7) (7=6) (8=9) (9=9) (10=9), gen(dropout_ISCED_v)

*field before dropout
gen dropout_field=m2_q27 
replace dropout_field=m2_q28 if missing(m2_q27 )

*training field
gen training_field_1=m2_q40_1 
gen training_field_2=m2_q40_2

*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q22 (19=0) (1=0) (2=1) (3=2) (4=2) (5=3) (6=3) (17=3) (7=4) (8=5) (9=5) (10=6), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q22==99
label var ISCED_needed "Education level need for the job"
notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13==3|m2_q13==9


}
/**** END OF VIETNAM ****/


/**** YUNNAN ****/
if country=="Yunnan" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define _ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 Gen" 6 "ISCED 4 Voc" 7 "ISCED 4 Gen" 8 "ISCED 5 Voc" 9 "ISCED 5  Gen & 6", replace
 
*highest education levels completed
recode m2_q08 (1=0) (2=1) (3=3) (4=2) (5=5) (6=4) (7=8) (8=9) (9=9) (10=9), gen(ISCED_vo)
recode m2_q15 (1=0) (2=1) (3=3) (4=2) (5=5) (6=4) (7=8) (8=9) (9=9) (10=9), gen(other_v) 

replace ISCED_vo=0 if m2_q02==2
gen ISCED_v=ISCED_vo
replace ISCED_v=other_v if other_v>ISCED_v & other_v<. /*Correct cases in which person should have a higher ISCED according to m2_q15*/

*Highest ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4)  (8=5) (9=5), gen(ISCED)
replace ISCED=0 if m2_q02==2

**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label val educ_voc educ_voc
label 	var	educ_voc	"Highest education level completed is vocational/general"

*HIGHEST ISCED, detailed
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (.=9) (.=10), gen(ISCED_p)
replace ISCED_p=6 if m2_q08==8 /*Bachelor's degree*/
replace ISCED_p=7 if m2_q08==9 /*Master's degree*/
replace ISCED_p=8 if m2_q08==10 /*PhD degree*/ 
replace ISCED_p=6 if ISCED_p==9 & m2_q15==8 /*correct for higher degree indicated in q15*/

replace ISCED_p=9 if m2_q08<. & ISCED_p==.
replace ISCED_p=10 if m2_q08==. & ISCED_p==. 

*highest level_field of study (combine general and vocational)
gen highest_field_1=m2_q08A_1  
replace highest_field_1=m2_q09_1 if missing( highest_field_1)
replace highest_field_1=m2_q11_1 if missing( highest_field_1)
replace highest_field_1=m2_q16 if other_v>ISCED_vo & other_v~=. & m2_q16~=.
replace highest_field_1=m2_q17 if other_v>ISCED_vo & other_v~=. & m2_q17~=.

gen highest_field_2=m2_q08A_2 
replace highest_field_2=m2_q09_2 if missing(highest_field_2)
replace highest_field_2=m2_q11_2 if missing(highest_field_2)

*current attending level
recode m2_q21 (1=0) (2=1) (3=2) (4=2) (5=3) (6=3) (7=5) (8=5)(9=5)(10=5), gen(current_ISCED)
recode m2_q21 (1=0) (2=1) (3=3) (4=2) (5=5) (6=4) (7=8) (8=9) (9=9) (10=9), gen(current_ISCED_v)

*current attending filed 
gen current_field=m2_q21A  
replace current_field=m2_q22 if missing(current_field)
replace current_field=m2_q23 if missing(current_field)

*level before dropout
recode m2_q26 (1=0) (2=1) (3=2) (4=2) (5=3) (6=3) (7=5) (8=5)(9=5)(10=5), gen(dropout_ISCED)
recode m2_q26 (1=0) (2=1) (3=3) (4=2) (5=5) (6=4) (7=8) (8=9) (9=9) (10=9), gen(dropout_ISCED_v)

*field before dropout
gen dropout_field=m2_q26A 
replace dropout_field=m2_q27 if missing(dropout_field)
replace dropout_field=m2_q28 if missing(dropout_field)

*YEARS OF EDUCATION
*recode m2_q08 (1=0) (2=6) (3=9) (4=9) (5=12) (6=12) (7=15) (8=16) (9=18)(10=20), gen(years_educ) /*Note that m2_q08 is not sufficient. Need to consider m2_q15 (or ISCED variables)*/
gen years_educ=0 if m2_q02==2
replace years_educ=3 if m2_q08==1 /*Assume that if have less than primary, did at least half of primary*/
replace years_educ=6 if ISCED_p==1 /*Primary (general or vocational)=6 years (max of UNESCO classification)*/
replace years_educ=9 if ISCED_v==2 /*Lower secondary (vocational)=9 years*/
replace years_educ=10 if ISCED_v==3 /*Lower secondary (general )=10 years*/
replace years_educ=13 if ISCED_p==3 /*Upper secondary (general or vocational)=13 years*/
replace years_educ=16 if ISCED_p==5 /*Vocational higher education=16 years*/
replace years_educ=17 if ISCED_p==6 /*Bachelors=16 years*/
replace years_educ=18 if ISCED_p==6 & (highest_field_1==15 | highest_field_1==17)/*Bachelor=17 years for medecine and engineering*/
replace years_educ=20 if ISCED_p==7 /*Masters=20 years*/
replace years_educ=24 if ISCED_p==8 /*PhD = 24 years*/

label var years_educ "Years of education corresponding to highest level of education completed"

*training field
gen training_field_1=m2_q40_1 
gen training_field_2=m2_q40_2

*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q22 (1=0) (2=1) (3=2) (4=2) (5=3) (6=3) (7=5) (8=5)(9=5)(10=6), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q22==99
label var ISCED_needed "Education level need for the job"
notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2|m2_q13==3	
replace school_location=3 if m2_q13==4

}
/**** END OF YUNNAN ****/


****************************
* LABEL VARIABLES EDUCATION *
****************************
label 	var	age	"Age"
label 	var	age2	"Age squared"
label 	var	occupationcode	"Occupation code"
label 	var	occupation	"Occupation"
label 	var	occtype	"Occupation type"
label 	var	tenure_range	"Time to learn to do job well with experience and education needed expressed as range"
label 	var	ece	"Attended preschool"
label 	var	certificate	"Has an industry-recognized or govt certificate not awarded by a formal ed institution"
label 	var	current	"Currently attending school"
label 	var	dropout	"Dropped out of highest educational level started"
label 	var	interrupt	"Interrupted studies for one academic year or more"
label 	var	training	"Participated in a training course in last 12 months"
label 	var	apprenticeship	"Has completed an apprenticeship"

label 	var	highest_field_1	"Field of highest degree (first reported)"
label 	var	highest_field_2	"Field of highest degree (second reported)"

label   var ISCED_p "Highest ISCED completed, PIAAC" 
label   var ISCED "Highest ISCED completed" 
label   var ISCED_v "Highest ISCED completed, with vocational distinction" 
label 	var	current_ISCED	"ISCED level currently attending"
label 	var	current_ISCED_v	"ISCED currently attending, with vocational distinction"
label 	var	current_field	"Field currently studying"
label 	var	dropout_ISCED	"Highest ISCED level before dropping out"
label 	var	dropout_ISCED_v	"Highest ISCED before dropping out, with vocational distinction"
label 	var	dropout_field	"Field studying before dropping out"

label 	var	training_field_1	"Field of skills training (first reported)"
label 	var	training_field_2	"Field of skills training (second reported)"

label define ISCED 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3 & 4A" 4 "ISCED 4B" 5 "ISCED 5 & 6", replace

label define ISCED_n 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3" 4 "ISCED 4" 5 "ISCED 5"  6 "ISCED 6", replace
label values ISCED_needed ISCED_n
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 Gen" 6 "ISCED 4 Voc" 7 "ISCED 4 Gen" 8 "ISCED 5 Voc" 9 "ISCED 5 Gen & 6", replace

label values  ISCED ISCED
label values  ISCED_p ISCED_p 
label values  ISCED_v ISCED_v 

label values  current_ISCED ISCED
label values  current_ISCED_v ISCED_v

label values  dropout_ISCED ISCED
label values  dropout_ISCED_v ISCED_v

label var years_educ "Number of years of education" 

label define yesno 1 "Yes" 0 "No", replace
label val ece yesno
label val certificate yesno 
lab val current yesno
lab val dropout yesno
lab val interrupt yesno
lab val training yesno
lab val apprenticeship yesno
lab val late_first_grade yesno
label var school_location "School location"
label define school_location 1 "In the same city" 2 "In another city/province" 3 "In another country"   
label values school_location school_location

*THIS SECTION generates:
	*categorical variables for education levels
	*Report higher level than necessary for the job
	*Aggregated education variable
*Report higher ISCED than necessary for the job
gen higher =1 if ISCED_dif>0 & ISCED_dif<.
replace higher=0 if ISCED_dif<. & ISCED_dif<=0
label var higher "Reports higher ISCED level than necessary for the job"
		

*******************
*NEW VOCATIONAL EDUC VARIABLE
******************
gen voc_ISCED=1 if ISCED==0
replace voc_ISCED=2 if ISCED==1 & educ_voc==1
replace voc_ISCED=3 if ISCED==1 & educ_voc==2
replace voc_ISCED=4 if ISCED==1 & educ_voc==3
replace voc_ISCED=5 if ISCED==2 & educ_voc==1
replace voc_ISCED=6 if ISCED==2 & educ_voc==2
replace voc_ISCED=7 if ISCED==2 & educ_voc==3
replace voc_ISCED=8 if ISCED==3 & educ_voc==1
replace voc_ISCED=9 if ISCED==3 & educ_voc==2
replace voc_ISCED=10 if ISCED==3 & educ_voc==3
replace voc_ISCED=11 if ISCED==4 & educ_voc==1
replace voc_ISCED=12 if ISCED==4 & educ_voc==2
replace voc_ISCED=13 if ISCED==4 & educ_voc==3
replace voc_ISCED=14 if ISCED==5 & educ_voc==1
replace voc_ISCED=15 if ISCED==5 & educ_voc==2
replace voc_ISCED=16 if ISCED==5 & educ_voc==3

label define voc_ISCED 1 "ISCED 0" 2 "ISCED 1 Voc" ///
								3 "ISCED 1 Gen & Voc" ///
								4 "ISCED 1 Gen" ///
								5 "ISCED 2 Voc" ///
								6 "ISCED 2 Gen & Voc" ///
								7 "ISCED 2 Gen" ///
								8 "ISCED 3 Voc" ///
								9 "ISCED 3 Gen & Voc" ///
								10 "ISCED 3 Gen" ///
								11 "ISCED 4 Voc" ///
								12 "ISCED 4 Gen & Voc" ///
								13 "ISCED 4 Gen" ///
								14 "ISCED 5 Voc" ///
								15 "ISCED 5 Gen & Voc" ///
								16 "ISCED 5 Gen", replace
label values voc_ISCED voc_ISCED
label var voc_ISCED "ISCED with voc & gen distinction"								
								

**************************************************** END OF EDUCATION SECTION ****************************************************
if country=="Colombia" {
label define urban 1 "Urban" 0 "Rural"
label values urban urban
label var urban "0: rural 1: urban"
rename WFinSPwt W_FinSPwt
rename WFinHHwt W_FinHHwt

order W_FinSPwt-W_FinS, after(country)
}

if country=="Sri Lanka" {
label var strata "Stratification variable"
drop roster_ISCED
}


	compress
	sort cluster hhn
	save "$pathworkingdata/STEP `country'_working.dta", replace
}





** THE STRUCTURE OF THE DATA FILES WAS SLIGTHLY DIFFERENT FOR UKRAINE
use "$pathworkingdata/STEP Ukraine_working.dta", clear

***************************************************************************************************************
************************** AGE, AGE GROUPS, GENDER AND OTHER DEMOGRAPHIC VARS *********************************
***************************************************************************************************************
*GENDER
gen gender =1 if m1a_q02 ==2
replace gender=0 if m1a_q02 ==1
label define gender 1 "Female" 0 "Male" 
label values gender gender
label var gender Gender

*AGE
gen age=m1a_q04

*AGE SQUARED
gen age2=age*age


*MARITAL STATUS /*DUMMY equal to one if person has a spouse*/
gen has_spouse=1 if m1a_q13==1|m1a_q13==2 |m1a_q13==3
replace has_spouse=0 if m1a_q13==4 |m1a_q13==5
replace has_spouse=0 if m1a_q13==6 
replace has_spouse=0 if m1a_q13==7
label 	var	has_spouse	"Has a spouse"
*replace marital_stat=5 if m1a_q13==8
*label define marital_stat 1 "Married/Cohab" 2 "Sep/Div" 3 "Widowed" 4 "Single" 5 "Other", replace

*LIFE SATISFACTION
gen life_sat=m3_q01_1
replace life_sat=.a if life_sat==97
label var life_sat "Life satisfaction"
 
*HAS A CHRONIC DISEASE
recode m3_q05(2=0), gen(chronic)
label define chronic 1 "Has a chronic disease" 0 "Doesn't have a chronic disease", replace
label values chronic chronic
label var chronic "Chronic disease" 
if country=="Ukraine" {
replace chronic=. if chronic==7
}


*NUMBER OF SIBLINGS AT AGE 12
gen old_brothers=m7a_q18
gen old_sisters=m7a_q19
gen young_brothers=m7a_q20
gen young_sisters=m7a_q21
replace old_brothers=.a if m7a_q18==92|m7a_q18==99|m7a_q18==97
replace old_sisters=.a if m7a_q19==92|m7a_q19==99|m7a_q19==97
replace young_brothers=.a if m7a_q20==92|m7a_q20==99|m7a_q20==97
replace young_sisters=.a if m7a_q21==92|m7a_q21==99|m7a_q21==97
label var young_brothers "Number of younger brothers at age 12"
label var young_sisters "Number of younger sisters at age 12"
label var old_brothers "Number of younger brothers at age 12"
label var old_sisters "Number of older sisters at age 12"


*FAMILY STRUCTURE AT AGE 12 
gen father_mother=1 if m7a_q22_1 ==1 & m7a_q22_2==1
replace father_mother=0 if m7a_q22_1==2 & m7a_q22_2==2
replace father_mother=2 if father_mother==.
label define father_mother 0 "Didn't live with father & mother"  2 "Lived with father & mother" 3 "DK/RF" 
label values father_mother father_mother
label var father_mother "Lived with mother and father at age 12"

*NUMBER OF SHOCKS BEFORE AGE 15

foreach num of numlist 1/11 {
foreach var of varlist m7a_q24_`num' {
recode m7a_q24_`num' (0=.) (2=0) (7/9=.)
}
}

gen shocks=(m7a_q24_1 + m7a_q24_2 + m7a_q24_3 + m7a_q24_4 + m7a_q24_5 + m7a_q24_6  + m7a_q24_7 + m7a_q24_8 + m7a_q24_9 + m7a_q24_10 )
replace shocks=shocks+1 if m7a_q24_11<. & m7a_q24_11!=0			   
label var shocks "Number of economic shocks before age 15" 
gen shocks2=shocks	
replace shocks2=2 if shocks2>=2 & shocks2<.
label define shocks2 0 "No shocks" 1 "One shock" 2 "Two or more shocks", replace
label values  shocks2 shocks2
label var shocks2 "Index for number of economic shocks before age 15" 
display "`country'" 
tab shocks2 if elegido==1

gen shocks_dummy=0 if shocks2==0	
replace shocks_dummy=1 if shocks2>=1 & shocks2<=2
label define shocks_dummy 0 "No shocks" 1 "At least one shock", replace
label values  shocks_dummy shocks_dummy
label var shocks_dummy "Dummy for economic shocks before age 15" 
*OVERWEIGHT, UNDERWEIGHT AND OBESITY
		recode m3_q03 (888=.) (9=.) (0=.) (997/999=.) /*WEIGHT*/
		recode m3_q02 (888=.) (9=.) (0=.) (997/999=.) /*HEIGHT*/ 
		replace m3_q02=m3_q02/100 /*Convert centimeters to meters*/
		gen BMI=m3_q03/(m3_q02*m3_q02) /*Weight over height squared*/
		replace BMI=round(BMI, .1)
		gen  BMI_class=1 if  BMI <18.5
		replace BMI_class=2 if BMI>18.5 & BMI<25
		replace BMI_class=3 if BMI>=25 & BMI <=29
		replace BMI_class=4 if BMI>=30 & BMI<. 
		label define BMI_class 1 Underweight 2 Normal 3 Overweight 4 Obese, replace 
		label values BMI_class BMI_class
		label var BMI_class "BMI classification" 
		label var BMI "Body Mass Index" 
		notes  BMI: "A BMI under 16 is extremely emaciated; a BMI of 15 signals starvation. BMI's over 40 signal morbid obesity." 
*PARENTAL INVOLVEMENT IN EDUCATION
	gen parental =m2_q46
	label var parental "Parental involvement in education"
	if country=="Ukraine" {
	replace parental=. if parental==7
	}
*SOCIOECONOMIC STATUS AT AGE 15
recode m7a_q23 (0=.) (1=1) (2=1) (3=1) (4=2) (5=2) (6=2) (7=3) (8=3) (9=3) (10=3) (97=.), gen(ses)
	label define ses 1 "Low SES" 2 "Middle SES" 3 "High SES", replace
	label values ses ses
	label var ses "Socioeconomic status at age 15"	
	
	
****** MOTHER TONGUE ******
if country=="Ukraine" {
	gen mother_tongue=1 if (m7a_q01_1==1 & m7a_q01_2==.) | (m7a_q01_2==1 & m7a_q01_1==.)	 								/* Ukranian Only */
	replace mother_tongue=2 if (m7a_q01_1==1 & m7a_q01_2~=1 & m7a_q01_2<.) | (m7a_q01_2==1 & m7a_q01_1~=1 & m7a_q01_1<.)	/* Ukranian and Others*/
	replace mother_tongue=3 if (m7a_q01_1==2 & m7a_q01_2==.) | (m7a_q01_2==2 & m7a_q01_1==.)								/* Russian Only */
	replace mother_tongue=4 if mother_tongue==. & (m7a_q01_1!=. | m7a_q01_2!=.) 											/* Others only*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Ukranian only" 2 "Ukranian and Other" 3 "Russian only" 4 "Others Only"
	lab values mother_tongue mother_tongue
}

	
****************************************** END OF AGE, AGE GROUPS, GENDER AND OTHER DEMOGRAPHIC VARS ******************************************


***************************************************************************************************************************
**************************************** LABOR MARKET *********************************************************************
***************************************************************************************************************************
/*"Employed" if:
- worked at least one hour in the past 7 days (q01-03)
- OR reported undertaking an occasional job in the past 7 days (q04)
- OR is currently absent from a permanent / long term job and will return to the same job (q05 & q06) */

/*  "Unemployed":
- did not work in the past 7 days (answered no to q01 to q04)
- AND is not currently absent from a permanent / long term job (no to q05) OR will not be returning to the same job (yes to q05, but either no or doesn't know to q06)
- AND is looking for a job (q07) or trying to set up a business (q08)
- AND is available to start work within the next two weeks */

/*"Out of the Labor Force if he or she:
- did not work in the past 7 days (answered no to q01 to q04)
- AND is not currently absent from a permanent / long term job (no to q05) OR will not be returning to the same job (yes to q05, but either no or doesn't know to q06)
- AND: 		(i) is NOT looking for a job (q07) NOR trying to set up a business (q08) 
		OR (ii) is looking for a job (q07) OR trying to set up a business (q08) AND, in either case, is not available to start work within the next two weeks (q12)*/

*emp: Dummy variable for worked or held a job in the past week
	gen emp=1 if m4a_q01==1|m4a_q02==1|m4a_q03==1|m4a_q04==1|m4a_q05==1|m4a_q06==1
	replace emp=0 if m4a_q01==2 & m4a_q02==2 & m4a_q03==2 & m4a_q04==2 & m4a_q05==2 
	replace emp=0 if m4a_q06==2
	replace emp=. if m4a_q06==9
	label var emp "Currently working"

*lm_status: Labor market status (employed, unemployed, inactive)	
	gen lm_status=1 if emp==1
	replace lm_status=2 if m4a_q07==1 & m4a_q12==1 /*Looking for work and available in next 2 weeks*/
	replace lm_status=2 if m4a_q08==1 & m4a_q12==1 /*Trying to start business and available in next 2 weeks*/
	replace lm_status=3 if m4a_q07==2 & m4a_q08==2 & lm_status==.  /*Hasn't looked for work/tried to start a business*/
	replace lm_status=3 if m4a_q07==1 & m4a_q12==2 /*Looking for work but not available in next 2 weeks*/
	replace lm_status=3 if m4a_q08==1 & m4a_q12==2 /*Trying to start business but not available in next 2 weeks*/
	label define  lm_status 1 "Employed" 2 "Unemployed" 3 "Inactive", replace
	label values lm_status lm_status
	label var lm_status "Labor market status"

	tab lm_status, m
*active: Dummy variable for being active in the labor market
	gen active=1 if lm_status==1|lm_status==2
	replace active=0 if lm_status==3 
	label define active 1 Active 0 Inactive
	label values active active
	label var active "Dummy for active in the labor market"

*emp_stat: employment status
if country=="Ukraine" {
	gen emp_status=.
	replace emp_status=1 if m4c_q06==1 & emp==1
	replace emp_status=2 if m4c_q06==2 & emp==1
	replace emp_status=2 if m4c_q06==3 & emp==1
	replace emp_status=3 if m4c_q06==4 & emp==1
	replace emp_status=3 if emp==1 & (m4c_q06~=1 & m4c_q06~=2 & m4c_q06~=3)
	lab define emp_status 1 "Employee" 2 "Self-employed" 3 "Unpaid family worker/other", replace
	lab values emp_status emp_status
	lab var emp_status "Employment status" 
	tab emp_status
}

*self_emp: SELF-EMPLOYMENT DUMMY
gen self_emp=1 if emp_stat==2
replace self_emp=0 if emp_stat==1
replace self_emp=0 if emp_stat==3
label var self_emp "Self-employment dummy"
label define self_emp 1 "Self-employed" 0 "Employee/Unpaid family worker/other", replace
label values self_emp self_emp 
	
*emplast12: DUMMY VARIABLE FOR WORKING OR WORKED IN THE LAST 12 MONTHS
	gen emplast12=1 if emp==1							/*Currently working*/	
	replace emplast12=1 if m5a_q02==1   				/*Worked in last 12 months*/
	replace emplast12 =0 if emp<. & emplast12==.
	label var emplast12 "Currently working or worked in last 12 months"

*emp6: DUMMY VARIABLE FOR INDIVIDUALS WHO HAVE WORKED AT LEAST 6 MONTHS SINCE COMPLETED HIGHEST LEVEL OF EDUCATION
	gen emp6=1 if m2_q30==1
	replace emp6 =0 if m2_q30==2  
	label var emp6 "Worked at least 6 months since completed highest level of education"
	notes emp6: Those currently attending formal ed (or w/o formal ed) do not answer this question. 

*Unemployed: 1=unemployed, 0=employed
gen unemployed=1 if lm_status==2
replace unemployed=0 if lm_status==1
label var unemployed "1=unemployed, 0=employed" 

*Employment
gen employed=1 if emp==1
		replace employed=0 if emp!=1 & lm_status<.
		label var employed "1=employed, 0=not employed"

*Wage workers
gen wage_worker=1 if emp_status==1
replace wage_worker=0 if emp==1 & emp_status!=1
label define wage_worker 1 "Wage-worker" 0 "Self-employed or family worker" 
label values wage_worker wage_worker
label var wage_worker "Percent of wage workers" 

*INACTIVE
if country=="Ukraine"{
gen inactive=.
replace inactive=1 if m4a_q09==2 /*Housewife*/
replace inactive=2 if m4a_q09==3|m4a_q09==4 /*Retired/old age*/
replace inactive=3 if m4a_q09==1 /*student*/
replace inactive=4 if m4a_q09==5|m4a_q09==7 | m4a_q09==51 | m4a_q09==52 /*unfit, don't want to work*/
replace inactive=5 if m4a_q09==12|m4a_q09==13 | m4a_q09==21  /*Discouraged*/
replace inactive=6 if m4a_q09==6|m4a_q09==8|m4a_q09==9|m4a_q09==10|m4a_q09==11 /*In transition*/
replace inactive=7 if m4a_q09==24 /*Other*/
replace inactive=8 if lm_stat==3 & inactive==. /*Looking for work but not available in 2 weeks*/
label define inactive 1 Housework 2 "Retired/old age" 3 Student 4 Unfit 5 Discouraged 6 "In transition" 7 Other 8 "Looking for work, not available in next 2 weeks" , replace
label values inactive inactive
label var inactive "Types of inactive population"
display "`country'"
tab inactive
}

*OCCUPATION
*recoding occupation

gen occupationcode=.
if country=="Ukraine" {
replace occupationcode=m4b_q01_code2
replace occupationcode=m4b_q01_code1 if m4b_q01_code1==10
replace occupationcode=. if m4b_q01_code2==199
label var occupationcode "ISCO Rev.8 occupation code"

gen occupation=.
replace occupation=1 if occupationcode>=11 & occupationcode<=14
replace occupation=2 if occupationcode>=21 & occupationcode<=26
replace occupation=3 if occupationcode>=31 & occupationcode<=36
replace occupation=4 if occupationcode>=41 & occupationcode<=44
replace occupation=5 if occupationcode>=51 & occupationcode<=54
replace occupation=6 if occupationcode>=61 & occupationcode<=63
replace occupation=7 if occupationcode>=70 & occupationcode<=75
replace occupation=8 if occupationcode>=81 & occupationcode<=87
replace occupation=9 if occupationcode>=91 & occupationcode<=96
replace occupation=0 if occupationcode>=0 & occupationcode<=10
label var occupation "1-digit ISCO Rev.8 occupation code"
}


*OCCUPATION TYPE
gen occtype=1 if occupation==1 | occupation==2 | occupation==3
replace occtype=2 if occupation>=4 & occupation<=9 
replace occtype=. if emp!=1 /*Only define this variable for currently employed*/

label define occtype 1 "Type A" 2 "Type B", replace
label values occtype occtype
tab occtype, gen(occtype)
rename occtype1 type_a
rename occtype2 type_b
label var type_a "Type A occupation"
label var type_b "Type B occupation"

	*OCCUPATION TYPE STEP Aggregation
	if country=="Ukraine" {
	gen occtype_step=.
	replace occtype_step=1 if occupationcode>=11 & occupationcode<=36
	replace occtype_step=2 if occupationcode>=41 & occupationcode<61
	replace occtype_step=5 if (occupationcode>=61 & occupationcode<=63)
	replace occtype_step=3 if occupationcode>=70 & occupationcode<=87
	replace occtype_step=4 if occupationcode>=91 & occupationcode<=96
	replace occtype_step=0 if occupationcode>=0 & occupationcode<=10
	label define occtype_step 0 "Military personnel" 1 "Highly skilled white collar - Managers/Professionals/Technicians" 2 "Low skilled white collar" ///
	                      3 "Crafts and related trades workers; Plant and machine operator and assemblers" 4 "Elementary occupations" 5 "Skilled agriculture work", replace
	label value occtype_step occtype_step
	label var occtype_step "Occupation Type (STEP Aggregation)"
	}
	
	*LAST OCCUPATION FOR UNEMPLOYED/INACTIVE
	gen last_occ_inun=.
	label var last_occ_inun "Last occupation for inactive/unemployed (STEP Aggregation" 
	
	*OCCUPATION FOR PEOPLE WHO WORKED IN LAST 12 MONTHS
	gen occtype_step_emp12=.
	label var occtype_step_emp12 "Most recent occupation for those who worked in last 12 months (STEP Aggregation)"	

	*ADDITIONAL OCCUPATION INACTIVE & UNEMPLOYED COULD DO (FIRST LISTED, USING TYPE 3 DEFINITION)
	gen     ad_occ_inun=.
	label var ad_occ_inun "First additional occupation, inactive/unemployed (STEP Aggregation)" 

	*ADDITIONAL OCCUPATION FOR PEOPLE CURRENTLY WORKING /*LIMITED TO THE FIRST ONE LISTED*/
	gen ad_occ_current=.
	label var ad_occ_current "First additional occupation, currently working (STEP Aggregation)"

	*ADDITIONAL OCCUPATION FOR PEOPLE WHO WORKED IN LAST 12 MONTHS /*LIMITED TO THE FIRST ONE LISTED*/
	gen ad_occ_emp12=.
	label var ad_occ_emp12 "First additional occupation, emp last 12 months (STEP Aggregation)"

	*PERMANENT POSITION 
	if country=="Ukraine" {
	/* Generating from other questions: E45*/
	
	gen permanent=1 if E45==1
	replace permanent=0 if E45~=1 & E45<7
	label var permanent "Permanent position" 
	notes permanent: Corresponds to main job. 
	}

	*GOVERNMENT EMPLOYMENT
	/*NOTE: Dummy only takes on values for employees. Should it be also take into account the self-employed in the zero category?*/
	*Dummy for government employee
	gen pub_emp=1 if m4c_q19==1|m4c_q19==2
	replace pub_emp=0 if m4c_q19<. & pub_emp!=1
	label var pub_emp "Public/Private employee"
	label define pub_emp 1 "public sector" 0 "private sector", replace
	label values pub_emp pub_emp
	label var pub_emp "Public or private sector employee"
	notes pub_emp: 1 = govt employee, 0=private employee
	notes pub_emp: Corresponds to main job. 
	
	*SIZE OF ESTABLISHMENT
	if country=="Ukraine" {
	gen size_est=1 if m4c_q21==1
	replace size_est=3 if inrange(m4c_q21, 5, 9)
	replace size_est=2 if inrange(m4c_q21, 2, 4)
	replace size_est=1 if m4c_q17==2 & size_est==. /*Self-employed who do not have paid employees*/
	replace size_est=1 if m4c_q16==2 & size_est==. /*Self-employed who do not have unpaid employees*/
	label define size_est 1 "One" 2 "2 to 20" 3 "21 and more", replace
	label values size_est size_est
	label var size_est "Category for number of paid workers in establishment"
	notes size_est: Corresponds to main job. 
	}
	
	*EMPLOYMENT CONTRACT
	if country=="Ukraine" {
	gen contract=1 if m4c_q18==1| m4c_q18==2 | m4c_q18==3
	replace contract=0 if m4c_q18==4
	label var contract "Has written employment contract" 
	notes contract: Corresponds to main job. 
	}
	
	*SOCIAL SECURITY BENEFITS
	if country=="Ukraine"{
	egen benefits=rowmax(m4c_q22_*)
	label var benefits "Receives social security benefits at work" 
	}
	
	*INFORMAL/FORMAL
	/* Assumptions:
	1. Individuals who are currently working and reported not having social security or benefits are informal
	2. Individuals who reported being an unpaid worke on family business are informal
	3. Individuals who reported being self employed and their reported size of establishment is 1 (including themselves) are informal
	*/

	gen informal=1 if benefits==0
	replace informal=0 if benefits==1  
	if country=="Ukraine" {
	replace informal=1 if (m4c_q06==4 | m4c_q06==5) & emp==1 /* ASSUMPTION: INDIVIDUALS WHO REPORTED 
																			BEING AN UNPAID WORKER IN FAMILY BUSINES*/
	}
	
	replace informal=1 if (m4c_q06==2 & size_est==1 & emp==1) & informal==. /*ASSUMPTION: INDIVIDUALS WHO REPORTED ///
																							BEING SELF EMPLOYED AND DO NOT HAVE PAID WORKERS ARE CONSIDERED INFORMAL*/
	label define informal 1 "Informal" 0 "Formal" 
	label values informal informal
	label var informal "Informal dummy"	
	
	gen informal_wage=1 if informal==1 & wage_worker==1
	replace informal_wage=0 if informal==0 & wage_worker==1
	gen informal_self=1 if informal==1 & self_emp==1
	replace informal_self=0 if informal==0 & self_emp==1
	label define informal_wage 1 "Informal wage worker" 0 "Formal wage worker", replace
	label values informal_wage informal_wage
	label var informal_wage "Informal (only wage workers)"
	label define informal_self 1 "Informal self-employed" 0 "Formal self-employed", replace
	label values informal_self informal_self
	label var informal_self "Informal (only self-employed)"
	notes  informal: "Informality is defined as having SS benefits through job" 
	notes  informal_wage: "Informality is defined as having SS benefits through job/unpaid family worker/other" 
	notes  informal_self: "Informality is defined as having SS benefits through job/unpaid family worker/other" 
	
	
*TENURE IN CURRENT JOB (use number of months so the variable can be squared)
	/*Note: some people have been working zero months*/
	 foreach var of varlist m4c_q03_m m4c_q03_y  {	 /*Change non-response to missing*/
		replace `var' = . if `var'==99 | `var' ==97
		} 
		
	if country=="Ukraine" {
	gen year2013=2013
	gen ref_date=mdy(MONTH_INT,1,year2013)
	gen cur_job_date=mdy(m4c_q03_m,1,m4c_q03_y)
	 gen tenure=(ref_date-cur_job_date)/30.4375
	 
	 gen tenure_squared=tenure*tenure           
	 label var tenure "Number of months in current job"
	 label var tenure_squared "Tenure squared"
	}

	drop year2013 ref_date cur_job_date
*EXPERIENCE NEEDED FOR JOB
	gen exp_needed=m5b_q23
	replace exp_needed=. if exp_needed==9 | exp_needed==7
	label define m5b_q23 1 "None" 2 "Less than 1 year" 3 "1-2 years" 4 "3-5 years" 5 "6-10 years" 6 "More than 10 years", replace 
	label values exp_needed m5b_q23
	label var exp_needed "Years of work experience needed for the job"
	notes exp_needed: Corresponds to main job. 

*TIME NEEDED TO DO A GOOD JOB
	gen time_needed=m5b_q24
	replace time_needed=. if time_needed==9 | time_needed==7
	label define time_needed 1 "Less than 1 week" 2 "1 week to 1 month" 3 "1-6 months" ///
							4 "7-12 months" 5 "More than 1 year" 6 "More than 10 years", replace 
	label values time_needed time_needed
	label var time_needed "Time to learn to do job well with experience and education needed"
	notes time_needed: Corresponds to main job.

*DOES PERSON'S TENURE FALL WITHIN THE TIME TO DO A GOOD JOB CATEGORIES?
	gen tenure_range=1 if tenure==0|tenure==1
	replace tenure_range=3 if tenure>=1 & tenure<=6
    replace tenure_range=4 if tenure>=7 & tenure<=12
	replace tenure_range=5 if tenure>12 & tenure<=120
	replace tenure_range=6 if tenure>120 & tenure<.
	*Combine less than a week with 1 week to a month
	recode time_needed (2=1), gen(time_needed2)
	
	gen tenure_dif=1 if (tenure_range-time_needed2)<0
	replace tenure_dif=2 if (tenure_range-time_needed2)==0
	replace tenure_dif=3 if (tenure_range-time_needed2)>0 & (tenure_range-time_needed2)<.
	label define tenure_dif 1 "Has less tenure than needed" 2 "Has same tenure as needed" 3 "Has more tenure than needed", replace
	label values tenure_dif tenure_dif
	label var tenure_dif "Difference between tenure and time needed to do job well" 
	
	drop time_needed2
	
*DIF B/T AGE & AGE AT END OF STUDIES
	gen exp_proxy=age-m2_q29
	label var exp_proxy "Diference between age and aprox age at end of studies"
	replace exp_proxy=. if exp_proxy<0 /*This variable should not be negative*/

*ECONOMIC SECTOR OF MAIN JOB
if country=="Ukraine"{
gen econ_sector=.
gen econ_sector_rev3=m4b_q04_code2
label var econ_sector_rev3 "Economic Sector (ISIC Rev.3)"

gen econ_sector_rev3_1=1 if inrange(econ_sector_rev3,1,14) /*Agriculture, fishery, mining*/
replace econ_sector_rev3_1=2 if inrange(econ_sector_rev3,15,36) /*Manufacturing*/
replace econ_sector_rev3_1=4 if inrange(econ_sector_rev3,37,41) /*Other Services*/
replace econ_sector_rev3_1=2 if m4b_q04_code1==4 /*Construction*/
replace econ_sector_rev3_1=3 if inrange(econ_sector_rev3,50,52) /*Commerce*/
replace econ_sector_rev3_1=4 if inrange(econ_sector_rev3,55,99) /*Other Services*/
replace econ_sector_rev3_1=4 if m4b_q04_code1==8 /*Other Services*/

	label var econ_sector_rev3_1 "Economic sector (Aggr.)"
	label define econ_sector_rev3_1 1 "Agriculture, fishery, mining" 2 "Manufacturing & construction" 3 "Commerce"  4 "Other services", replace
	label values econ_sector_rev3_1 econ_sector_rev3_1

}
	label var econ_sector "Economic sector"
	label define econ_sector 1 "Agriculture, fishery, mining" 2 "Manufacturing & construction" 3 "Commerce"  4 "Other services", replace
	label values econ_sector econ_sector		
		
*FOR SELF-EMPLOYED: WOULD LIKE TO EXPAND BUSINESS
gen expand=1 if m4c_q10==2
replace expand=2 if m4c_q11==1
replace expand=3 if m4c_q11==2
label define expand 1 "No" 2 "Yes, but constraint" 3 "Yes, no constraint" 
label var expand "Desire to expand business and if so, if face constraints"
label values expand expand

*NET PROFIT (FOR SELF-EMPLOYED)
gen net_profit =.
replace net_profit=.a if m4c_q09_amnt==92 | m4c_q09_amnt==997 | m4c_q09_amnt==999
replace net_profit =.a if m4c_q09_amnt==1.2 /*STRANGE NUMBER*/
replace net_profit=m4c_q09_amnt*4 if m4c_q09_period==1 /*week*/
replace net_profit=m4c_q09_amnt if m4c_q09_period==2 /*month*/
replace net_profit=m4c_q09_amnt*2 if m4c_q09_period==3 /*fortnight*/
replace net_profit=m4c_q09_amnt/3 if m4c_q09_period==4 /*trimester*/
replace net_profit=m4c_q09_amnt/6 if m4c_q09_period==5 /*semester*/
replace net_profit=m4c_q09_amnt/12 if m4c_q09_period==6 /*year*/
replace net_profit=m4c_q09_amnt*30.42 if m4c_q09_period==8 /*day*/
replace net_profit=.a if m4c_q09_period==7|m4c_q09_period==9|m4c_q09_period==0 /*contract or don't know*/
label var net_profit "Net monthly profit from business" 
	
****************************************************************************************************************************
*HOURLY LABOR earnings             
****************************************************************************************************************************
*NUMBER OF HOURS WORKED LAST WEEK
	/*NOTE THAT SOME WORKERS REPORT HAVING NOT WORKED DURING THE LAST WEEK. THESE OBSERVATIONS ARE CHANGED TO MISSING*/
	if country=="Ukraine" {
	gen hours=m4b_q06_1
	label var hours "Number of hours worked last week in main occupation"
	gen hours_d=.
	label var hours_d "Average number of hours worked daily in main occupation"																			
	
	}
	
*HOURLY LABOR earnings 
	/*NOTES: 1. Assume that "last week" was a typical workweek. 
			 2. Use 4.35 as # of weeks in one month, 21.7 as # of week days in a month.
			 3. Assume net profits are not shared with other investors.
			 4. earnings with "other" pay periods have to be computed by hand. Some of these cannot
			   be computed, however, as they do not correspond to time periods per se or are not specified.*/
	
	notes: The questionnaire for Ukraine was structured differently to the STEP Master BQ
		// For Wage Earners:
		// 		Use the "Offical salary" as a proxy for earnings, because "Actual salary" and "Paid unofficially, through enveloppe" had too much missing data on pay periods	
		// For Sel-employed Respondents:
		//		Use question on Question E79B on amount received from the business / own account enterprise in the last work period, as this question is closest to the STEP Master BQ
	
	rename m4c_q25_a m4c_q25

	* Earnings for Wage Earners
	* What respondent was supposed to receive - official salary
	tab E54
	notes: over 90% of respondents report that the salary they were supposed to receive (official salary) is the same as the one they actually received -> OK to use official salary as a proxy for actual salary
	drop E54
	gen earnings_hw=.
	replace earnings_hw=E52A/hours/4.35 if E52B==1   				/*earnings for wage earners, 1 month*/
	replace earnings_hw = E52A/hours/2.17 if E52B==2 				/*earnings for wage earners,  2 weeks*/
	replace earnings_hw = E52A/hours  if E52B==3 				    /*earnings for wage earners,  1 week*/
	replace earnings_hw = E52A/8  if E52B==4     				    /*earnings for wage earners, 1 day, use 8 hours as a proxy*/
	replace earnings_hw=. if E52A==7 | E52A==8 | E52A==9
	
	
	* Earnings for Self-employed respondents
	notes: use question E.79B: Last amount received in the last work period as is closest to the STEP BQ question
	gen earnings_hse=.
	replace earnings_hse=m4c_q27/hours/4.35 if m4c_q28==1   			/*earnings for wage earners, 1 month*/
	replace earnings_hse = m4c_q27/hours/2.17 if m4c_q28==2 			/*earnings for wage earners,  2 weeks*/
	replace earnings_hse = m4c_q27/hours  if m4c_q28==3					/*earnings for wage earners,  1 week*/
	replace earnings_hse = m4c_q27/8  if m4c_q28==4     				/*earnings for wage earners, 1 day, use 8 hours as a proxy*/
	replace earnings_hse = . if m4c_q27==997 | m4c_q27==999

	sort emp_status
	by emp_status: su earnings_h*
	// OK: consistent data -> wage employed have earnings from wage employed section & self-employed have earnings from se question

	gen earnings_h=.
	replace earnings_h=earnings_hw if emp_status==1
	replace earnings_h=earnings_hse if emp_status==2
	drop earnings_hw earnings_hse
	label var earnings_h "Hourly labor earnings" 
	notes earnings_h: earnings for wage earners is net of taxes and benefits. earnings for self-employed is gross.  
	notes earnings_h: Corresponds to main occupation. 

	
/*Calcuate hourly earnings for people who specify a different pay period*/
gen ln_earnings_h=log(earnings_h + 0.0000000000000000000001)
label var ln_earnings_h "Log of hourly earnings" 


*UNDEREMPLOYED 
if country=="Ukraine" {
gen total_hours_week=m4c_q06
}

gen underemp=1 if m4b_q09==1 & total_hours_week<35
replace underemp=0 if m4b_q09==2 
replace underemp=0 if total_hours_week>=35 & m4b_q09==1 & total_hours_week<.
label define underemp 0 "Not underemployed"  1 "Underemployed", replace 
label values underemp underemp
label var underemp "Underemployed"
notes underemp: Refers to working under 35 hours/week and wanting to work more hours for the same pay.
label var total_hours_week "Total hours worked during the week, all jobs"

*SOURCE OF FUNDS (FOR SELF-EMPLOYED)
if country=="Ukraine" {
gen source_funds=1 if m4c_q07_1==1 | m4c_q07_2==1 | m4c_q07_3==1 | m4c_q07_4==1
replace source_funds=0 if source_funds==.
}

label var source_funds "Source of funds for starting business" 
label define source_funds 1 "Used family money" 0 "Did not use family money", replace
label values source_funds source_funds

*SIZE OF BUSINESS AT START
gen business_size=1 if m4c_q08==1
replace business_size=0 if m4c_q08>1 & m4c_q08<.
label var business_size "Size of business at start"
label define business_size 1 "One person" 0 "More than 1 person", replace
label values business_size business_size


**************************************************** END OF LABOR MARKET SECTION ****************************************************


***********************************************************************************************************************************************
*********************************************************     EDUCATION VARIABLES     *********************************************************
***********************************************************************************************************************************************

*ece (don't know's=missing)
gen ece=1 if m2_q01==1
replace ece=0 if m2_q01==2
*certification not awarded by a formal education institution
gen certificate=0 
if country!="Colombia" {
	replace certificate=1 if m2_q18==1 | m2_q05==1		/* There is no question 18 in the Colombian Q */
}

*currently attending
gen current=1 if m2_q20==1
replace current=0 if  m2_q20==2
replace current=0 if m2_q02==2
*dropout
gen dropout=1 if m2_q24==1
replace dropout=0 if m2_q24==2
replace dropout=0 if current==1 /*If currently attending, don't answer this question*/
*interrupt
gen interrupt=1 if m2_q37==1
replace interrupt=0 if m2_q37==2
*training
gen training=1 if m2_q39==1
replace training=0 if m2_q39==2
*apprenticeship
gen apprenticeship=1 if m2_q41==1
replace apprenticeship=0 if m2_q41==2
*age started first grade
gen late_first_grade=1 if m2_q07>=8 & m2_q07<.
replace late_first_grade=0 if m2_q07<8
label var late_first_grade "Started first grade at age 8 or older"
*type of school attended
gen school_type = 1 if m2_q12==1
replace school_type=2 if m2_q12==2|m2_q12==3
replace school_type=3 if m2_q12==4|m2_q12==5|m2_q12==9
label define school_type 1 "Public" 2 "Private" 3 "Other"
label values school_type school_type
label var school_type "Type of school attended"  
*Age started school
gen age_start=m2_q07
recode age_start (92=.) (99=.)
label var age_start "Age started first grade" 


****************************************** EDUCATION LEVELS AND FIELD ******************************************
**************************** COUNTRY BY COUNTRY AS MODULE 2 IS COUNTRY-SPECIFIC ********************************
/**** Ukraine ***/

if country=="Ukraine" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 A" 6 "ISCED 4 Voc" 7 "ISCED 4 A" 8 "ISCED 5 Voc" 9 "ISCED 5 A & 6", replace

		/*LABL: The following are the labels for m2_q08, m2_q15, m2_q21, m2_q26
        0 No formal education                                 
		1 Pre- primary education
		2 Primary education                                     
		3 Basic secondary education                        
		4 Full secondary education (obtained a high school attestat)                       
		5 Obtained qualification diploma and attestat of completion of full secondary educationfrom PTU, FZU, FZO etc. (which you entered upon completion of basic secondary education)             
		6 Qualification diplomaof PTU, FZU, FZO etc. (which you entered upon completion of full secondary education)  
		7 Secondary special education that you entered upon completion of basic secondary education (as it used to be in former USSR) 
		8 Secondary special education that you entered upon completion of full secondary education (as it used to be in former USSR) 
		9 Complete higher education (without specification of the diploma type as it used to be in former USSR)  
		10 Degree of junior specialistcombined with full general secondary education from higher education institutionthat you entered upon completion of basic secondary education
		11 Degree of junior specialistfrom institute, university, academy or other higher education institutionthat you entered upon completion of full secondary education 
		12 Bachelor degreefrom institute, university, academy or other higher education institution
		13 Diploma of specialistfrom institute, university, academy or other higher education institution
		14 Master degreefrom institute, university, academy or other higher education institution
		15 Candidate of sciences, doctor of sciences 
		16 OTHER [RECORD] 
		97 DS
		99 RA
		*/
		
*NEED TO DECIDE WHAT TO DO ABOUT 4A 
*highest level completed with vocation distinction (ISCED_v)
recode m2_q08 (0=0) (1=0) (2=1) (3=3) (4=5) (5=4) (6=6) (7=4) (8=8) (9=9) (10=4) (11=8) (12=9) (13=9) (14=9) (15=9) (97/99=.), gen(ISCED_v)
recode m2_q15 (0=0) (1=0) (2=1) (3=3) (4=5) (5=4) (6=6) (7=4) (8=8) (9=9) (10=4) (11=8) (12=9) (13=9) (14=9) (15=9) (97/99=.), gen(other_v)
replace ISCED_v=other_v if other_v>ISCED_v & other_v<. /*According to Giovanna, it is necessary to use m2_q15 to 
																	calculate highest level of edcuation completed*/

replace ISCED_v=0 if m2_q02==2  						 /*Did not attend school*/



*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5), gen(ISCED) /*4A is grouped with 3 because it (pre-university 6 month course) is not really 4A*/


**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p) /*here 4A hasn't been grouped with 3*/
replace ISCED_p=6 if m2_q08==12 /*Bachelor's degree*/
replace ISCED_p=7 if m2_q08==9 | m2_q08==13 | m2_q08==14 /*Master's degree*/
replace ISCED_p=8 if m2_q08==15 /*PhD degree*/ 
replace ISCED_p=9 if m2_q08<. & ISCED_p==.
replace ISCED_p=10 if m2_q08==. & ISCED_p==. 
notes  ISCED: People who have attended pre-university courses are grouped in ISCED 3. 

*current attending level
recode m2_q21 (0=0) (1=0) (2=1) (3=3) (4=5) (5=4) (6=6) (7=4) (8=8) (9=9) (10=4) (11=8) (12=9) (13=9) (14=9) (15=9) (97/99=.), gen(current_ISCED_v) 
recode m2_q21 (0=0) (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=7) (10=3) (11=5) (12=6) (13=7) (14=7) (15=8) (97/99=.), gen(current_ISCED_p)
recode m2_q21 (0=0) (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5) (10=3) (11=5) (12=5) (13=5) (14=5) (15=6) (97/99=.), gen(current_ISCED)
  
*level before dropout
recode m2_q26 (0=0) (1=0) (2=1) (3=3) (4=5) (5=4) (6=6) (7=4) (8=8) (9=9) (10=4) (11=8) (12=9) (13=9) (14=9) (15=9) (97/99=.), gen(dropout_ISCED_v) 
recode m2_q26 (0=0) (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=7) (10=3) (11=5) (12=6) (13=7) (14=7) (15=8) (97/99=.), gen(dropout_ISCED_p)
recode m2_q26 (0=0) (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5) (10=3) (11=5) (12=5) (13=5) (14=5) (15=6) (97/99=.), gen(dropout_ISCED)

gen highest=m2_q08
gen highest2=m2_q15
gen hgsteduc=max(highest, highest2)
gen hgstcurrent=m2_q21
gen hgstdrop=m2_q26


*NUMBER OF YEARS OF EDUCATION (GP & TR)
gen years_educ=0 if m2_q02==2 /*No formal education*/
replace years_educ=0 if hgsteduc==1 		/* Pre-primary education */
replace years_educ=4 if hgsteduc==2 		/* Primary education*/
replace years_educ=9 if hgsteduc==3 		/* Basic Secondary education*/
replace years_educ=11 if hgsteduc==4		/* Full Secondary education (Obtained Attestat)*/
replace years_educ=11 if hgsteduc==5 	/* Obtained Qualification Diploma and Attestat of complition of full secondary education*/
replace years_educ=12 if hgsteduc==6 	/* Qualification diploma of PTU, FZU, FZO (which you entered upon completionof full secondary education)*/
replace years_educ=13 if hgsteduc==7 	/* Secondary special education that you entered upon completion of basic secondary education (as it used to be in Former USSR)*/
replace years_educ=13 if hgsteduc==8 	/* Secondary special education that you entered upon completion of full secondary education (as it used to be in Former USSR)*/
replace years_educ=16 if hgsteduc==9 	/* Complete higher education (without specification of the diploma type as it used to be in Former USSR)*/
	notes: Assumption is that they have completed hihger education III-IV accreditation level which would give them a masters degree	
replace years_educ=13 if hgsteduc==10 	/* Degree of junior specialist combidned with full general secondary education*/
replace years_educ=14 if hgsteduc==11 	/* Degree of junior specialist from institute, university, academy or other higher education institution*/
replace years_educ=15 if hgsteduc==12 	/* Bachelor Degree from institute, university, academy or other higher education institution*/
replace years_educ=16 if hgsteduc==13 	/* Diploma of specialist from institute, university academy or other higher education institution*/
replace years_educ=16 if hgsteduc==14 	/* Master degree from institute, university, academy or other higher education institution*/
replace years_educ=22 if hgsteduc==15 	/* Candidate of sciences, doctor of sciences*/
	notes: assumption is that they have completed the Candidate of Science. 

label var years_educ "Years of education corresponding to highest level of education completed"

gen m2_q09_1=.
forvalues i=1(1)13 {
replace m2_q09_1=`i' if m2_q09_1_`i'==1 & m2_q09_1==.
}
replace m2_q09_1=97 if m2_q09_1_97==1
replace m2_q09_1=99 if m2_q09_1_99==1

label define field_educ 1 "General or no specific field" 2 "Education" 3 "Busines administration, accountancy, commerce, retail shop management, economics, etc" ///
						4 "Public Administration and planning" 5 "Law and legal services" 6 "Medical, health services, nursing, etc" 7 "Science, mathematics, computing, etc" ///
						8 "Other technical & engineering, including architecture, industry, craft, building trades, etc" 9 "Agriculture, livestock, forestry" ///
						10 "Social & behavioural studies, media, culture, sport and leisure studies, tourism, etc" 11 "Art or Humanities - languages, classics, history, theology,etc" ///
						12 "Personal care services - catering, domestic science, hairdressing, etc" 13 "Public order and safety - police army, fire services, etc" ///
						14 "Other" 97 "DS" 99 "RA" 
label values m2_q09_1 field_educ
label var m2_q09_1 "G10 In what field is this sertificate or qualification? - Consolidated"						

*highest field of study (combine general and vocational)
*the variable highest_field does not have a label*
*highest field corresponds to highest education level corrected for m2_q15*

gen highest_field_1=m2_q09_1 
replace highest_field_1=m2_q11_1 if missing( highest_field_1)
replace highest_field_1=. if hgsteduc>highest & hgsteduc~=.
replace highest_field_1=m2_q16 if m2_q16~=. & hgsteduc==highest2 & hgsteduc>highest
replace highest_field_1=m2_q17 if m2_q17~=. & hgsteduc==highest2 & hgsteduc>highest

gen highest_field_2=.

drop highest highest2 hgsteduc


*number of degrees *PENDING
/*gen numb_deg_same_level=1 if highest_field_1<. & highest_field_2==.
replace numb_deg_same_level=2 if highest_field_2<.
replace numb_deg_same_level=3 if m2_q15*/

/*gen numb_deg_lower_level=1 if m*/
*current attending field 

gen current_field=m2_q22 
replace current_field=m2_q23 if missing(current_field) 

*field before dropout
gen dropout_field=m2_q27 
replace dropout_field=m2_q28 if missing(m2_q27 )

*training field

gen m2_q40_1=.
forvalues i=1(1)15 {
replace m2_q40_1=`i' if m2_q40_1_`i'==1 & m2_q40_1==.
}
replace m2_q40_1=97 if m2_q40_1_97==1
replace m2_q40_1=99 if m2_q40_1_99==1

label var m2_q40_1 "G40 In what field is this certificate or qualification? - Consolidated"	

gen training_field_1=m2_q40_1 
gen training_field_2=.


*EDUCATION LEVEL NEEDED FOR JOB
*LEVEL 4A is not meant to lead to the labor market. It is thus strange that some people say that pre-university courses (6)
*are required for the job. We consider this ISCED 3, as is the case when definining ISCED levels. 
recode m5b_q22 (0=0) (1=0) (2=1) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5) (10=3) (11=5) (12=5) (13=5) (14=5) (15=6) (97/99=.), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q22==16
label var ISCED_needed "Education level need for the job"
notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13==3|m2_q13==9


}


****************************
* LABEL VARIABLES EDUCATION *
****************************
label 	var	age	"Age"
label 	var	age2	"Age squared"
label 	var	occupationcode	"Occupation code"
label 	var	occupation	"Occupation"
label 	var	occtype	"Occupation type"
label 	var	tenure_range	"Time to learn to do job well with experience and education needed expressed as range"
label 	var	ece	"Attended preschool"
label 	var	certificate	"Has an industry-recognized or govt certificate not awarded by a formal ed institution"
label 	var	current	"Currently attending school"
label 	var	dropout	"Dropped out of highest educational level started"
label 	var	interrupt	"Interrupted studies for one academic year or more"
label 	var	training	"Participated in a training course in last 12 months"
label 	var	apprenticeship	"Has completed an apprenticeship"

label 	var	highest_field_1	"Field of highest degree (first reported)"
label 	var	highest_field_2	"Field of highest degree (second reported)"

label   var ISCED_p "Highest ISCED completed, PIAAC" 
label   var ISCED "Highest ISCED completed" 
label   var ISCED_v "Highest ISCED completed, with vocational distinction" 
label 	var	current_ISCED	"ISCED level currently attending"
label 	var	current_ISCED_v	"ISCED currently attending, with vocational distinction"
label 	var	current_field	"Field currently studying"
label 	var	dropout_ISCED	"Highest ISCED level before dropping out"
label 	var	dropout_ISCED_v	"Highest ISCED before dropping out, with vocational distinction"
label 	var	dropout_field	"Field studying before dropping out"

label 	var	training_field_1	"Field of skills training (first reported)"
label 	var	training_field_2	"Field of skills training (second reported)"

label define ISCED 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3 & 4A" 4 "ISCED 4B" 5 "ISCED 5 & 6", replace

label define ISCED_n 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3" 4 "ISCED 4" 5 "ISCED 5"  6 "ISCED 6", replace
label values ISCED_needed ISCED_n
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 Gen" 6 "ISCED 4 Voc" 7 "ISCED 4 Gen" 8 "ISCED 5 Voc" 9 "ISCED 5 Gen & 6", replace

label values  ISCED ISCED
label values  ISCED_p ISCED_p 
label values  ISCED_v ISCED_v 

label values  current_ISCED ISCED
label values  current_ISCED_v ISCED_v

label values  dropout_ISCED ISCED
label values  dropout_ISCED_v ISCED_v

label var years_educ "Number of years of education" 

label define yesno 1 "Yes" 0 "No", replace
label val ece yesno
label val certificate yesno 
lab val current yesno
lab val dropout yesno
lab val interrupt yesno
lab val training yesno
lab val apprenticeship yesno
lab val late_first_grade yesno
label var school_location "School location"
label define school_location 1 "In the same city" 2 "In another city/province" 3 "In another country"   
label values school_location school_location

*THIS SECTION generates:
	*categorical variables for education levels
	*Report higher level than necessary for the job
	*Aggregated education variable
*Report higher ISCED than necessary for the job
gen higher =1 if ISCED_dif>0 & ISCED_dif<.
replace higher=0 if ISCED_dif<. & ISCED_dif<=0
label var higher "Reports higher ISCED level than necessary for the job"
		


*******************
*NEW VOCATIONAL EDUC VARIABLE
******************
gen voc_ISCED=1 if ISCED==0
replace voc_ISCED=2 if ISCED==1 & educ_voc==1
replace voc_ISCED=3 if ISCED==1 & educ_voc==2
replace voc_ISCED=4 if ISCED==1 & educ_voc==3
replace voc_ISCED=5 if ISCED==2 & educ_voc==1
replace voc_ISCED=6 if ISCED==2 & educ_voc==2
replace voc_ISCED=7 if ISCED==2 & educ_voc==3
replace voc_ISCED=8 if ISCED==3 & educ_voc==1
replace voc_ISCED=9 if ISCED==3 & educ_voc==2
replace voc_ISCED=10 if ISCED==3 & educ_voc==3
replace voc_ISCED=11 if ISCED==4 & educ_voc==1
replace voc_ISCED=12 if ISCED==4 & educ_voc==2
replace voc_ISCED=13 if ISCED==4 & educ_voc==3
replace voc_ISCED=14 if ISCED==5 & educ_voc==1
replace voc_ISCED=15 if ISCED==5 & educ_voc==2
replace voc_ISCED=16 if ISCED==5 & educ_voc==3

label define voc_ISCED 1 "ISCED 0" 2 "ISCED 1 Voc" ///
								3 "ISCED 1 Gen & Voc" ///
								4 "ISCED 1 Gen" ///
								5 "ISCED 2 Voc" ///
								6 "ISCED 2 Gen & Voc" ///
								7 "ISCED 2 Gen" ///
								8 "ISCED 3 Voc" ///
								9 "ISCED 3 Gen & Voc" ///
								10 "ISCED 3 Gen" ///
								11 "ISCED 4 Voc" ///
								12 "ISCED 4 Gen & Voc" ///
								13 "ISCED 4 Gen" ///
								14 "ISCED 5 Voc" ///
								15 "ISCED 5 Gen & Voc" ///
								16 "ISCED 5 Gen", replace
label values voc_ISCED voc_ISCED
label var voc_ISCED "ISCED with voc & gen distinction"								
								

**************************************************** END OF EDUCATION SECTION ****************************************************
drop hgstcurrent hgstdrop
	compress
	sort cluster hhn
	save "$pathworkingdata/STEP Ukraine_working.dta", replace


**************************************************************************** END OF STEP DO-FILE 5 ******************************************************************
